window.Gleam.initSearch([{"doc":"telega","title":"telega","content":"# Telega\n\n[![Package Version](https://img.shields.io/hexpm/v/telega)](https://hex.pm/packages/telega)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/telega/)\n\nA [Gleam](https://gleam.run/) library for the Telegram Bot API.\n\n## It provides\n\n- an interface to the Telegram Bot HTTP-based APIs `telega/api`\n- adapter to use with [wisp](https://github.com/gleam-wisp/wisp)\n- session bot implementation\n- conversation implementation\n\n## Quick start\n\n&gt; If you are new to Telegram bots, read the official [Introduction for Developers](https://core.telegram.org/bots) written by the Telegram team.\n\nFirst, visit [@BotFather](https://t.me/botfather) to create a new bot. Copy **the token** and save it for later.\n\nInitiate a gleam project and add `telega` and `wisp` as a dependencies:\n\n```sh\n$ gleam new first_tg_bot\n$ cd first_tg_bot\n$ gleam add telega wisp mist gleam_erlang\n```\n\nReplace the `first_tg_bot.gleam` file content with the following code:\n\n```gleam\nimport gleam/erlang/process\nimport gleam/option.{None}\nimport gleam/result\nimport mist\nimport telega\nimport telega/adapters/wisp as telega_wisp\nimport telega/reply\nimport telega/update.{CommandUpdate, TextUpdate}\nimport wisp\n\nfn handle_request(bot, req) {\n  use &lt;- telega_wisp.handle_bot(req, bot)\n  wisp.not_found()\n}\n\nfn echo_handler(ctx) {\n  use &lt;- telega.log_context(ctx, &quot;echo&quot;)\n\n  case ctx.update {\n    TextUpdate(text:, ..) -&gt; reply.with_text(ctx, text)\n    CommandUpdate(command:, ..) -&gt; reply.with_text(ctx, command.text)\n    _ -&gt; Error(&quot;No text message&quot;)\n  }\n  |&gt; result.map(fn(_) { Nil })\n}\n\npub fn main() {\n  wisp.configure_logger()\n\n  let assert Ok(bot) =\n    telega.new(\n      token: &quot;your bot token from @BotFather&quot;,\n      url: &quot;your bot url&quot;,\n      webhook_path: &quot;secret path&quot;,\n      secret_token: None,\n    )\n    |&gt; telega.handle_all(echo_handler)\n    |&gt; telega.init_nil_session\n\n  let assert Ok(_) =\n    wisp.mist_handler(handle_request(bot, _), wisp.random_string(64))\n    |&gt; mist.new\n    |&gt; mist.port(8000)\n    |&gt; mist.start_http\n\n  process.sleep_forever()\n}\n```\n\nReplace `&quot;your bot token from @BotFather&quot;` with the token you received from the BotFather. Set the `url` and `webhook_path` to your server&#39;s URL and the desired path for the webhook. If you don&#39;t have a server yet, you can use [ngrok](https://ngrok.com/) or [localtunne](https://localtunnel.me/) to create a tunnel to your local machine.\n\nThen run the bot:\n\n```sh\n$ gleam run\n```\n\nAnd it will echo all received text messages.\n\nCongratulations! You just wrote a Telegram bot :)\n\n## Examples\n\nOther examples can be found in the [examples](./examples) directory.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"telega/log","title":"debug","content":"pub fn debug(message: a) -&gt; Nil\n\nSynonyms:\ntelega/log.debug\ntelega/log debug","url":"telega/log.html#debug"},{"doc":"telega/log","title":"debug_d","content":"pub fn debug_d(message: a) -&gt; Nil\n\nSynonyms:\ntelega/log.debug_d\ntelega/log debug_d","url":"telega/log.html#debug_d"},{"doc":"telega/log","title":"error","content":"pub fn error(message: String) -&gt; Nil\n\nSynonyms:\ntelega/log.error\ntelega/log error","url":"telega/log.html#error"},{"doc":"telega/log","title":"error_d","content":"pub fn error_d(message: a) -&gt; Nil\n\nSynonyms:\ntelega/log.error_d\ntelega/log error_d","url":"telega/log.html#error_d"},{"doc":"telega/log","title":"info","content":"pub fn info(message: String) -&gt; Nil\n\nSynonyms:\ntelega/log.info\ntelega/log info","url":"telega/log.html#info"},{"doc":"telega/log","title":"info_d","content":"pub fn info_d(message: a) -&gt; Nil\n\nSynonyms:\ntelega/log.info_d\ntelega/log info_d","url":"telega/log.html#info_d"},{"doc":"telega/log","title":"warn","content":"pub fn warn(message: String) -&gt; Nil\n\nSynonyms:\ntelega/log.warn\ntelega/log warn","url":"telega/log.html#warn"},{"doc":"telega/log","title":"warn_d","content":"pub fn warn_d(message: a) -&gt; Nil\n\nSynonyms:\ntelega/log.warn_d\ntelega/log warn_d","url":"telega/log.html#warn_d"},{"doc":"telega/log","title":"telega/log","content":"","url":"telega/log.html"},{"doc":"telega/model","title":"AnswerCallbackQueryParameters","content":"pub type AnswerCallbackQueryParameters {\n  AnswerCallbackQueryParameters(\n    callback_query_id: String,\n    text: Option(String),\n    show_alert: Option(Bool),\n    url: Option(String),\n    cache_time: Option(Int),\n  )\n}\n\nAnswerCallbackQueryParameters(\n  callback_query_id: String,\n  text: Option(String),\n  show_alert: Option(Bool),\n  url: Option(String),\n  cache_time: Option(Int),\n)\n\ncallback_query_id\n&lt;p&gt;Unique identifier for the query to be answered&lt;/p&gt;\n\ntext\n&lt;p&gt;Text of the notification. If not specified, nothing will be shown to the user&lt;/p&gt;\n\nshow_alert\n&lt;p&gt;If true, an alert will be shown by the client instead of a notification at the top of the chat screen. Defaults to false.&lt;/p&gt;\n\nurl\n&lt;p&gt;URL that will be opened by the user’s client. If you have created a &lt;a href=&quot;https://core.telegram.org/bots/api#games&quot;&gt;Game&lt;/a&gt;, you can use this\nfield to redirect the player to your game&lt;/p&gt;\n\ncache_time\n&lt;p&gt;The maximum amount of time in seconds that the result of the callback query may be cached client-side. Telegram apps will support\ncaching starting in version 3.14. Defaults to 0.&lt;/p&gt;\n\nSynonyms:\ntelega/model.AnswerCallbackQueryParameters\ntelega/model AnswerCallbackQueryParameters","url":"telega/model.html#AnswerCallbackQueryParameters"},{"doc":"telega/model","title":"BotCommand","content":"pub type BotCommand {\n  BotCommand(command: String, description: String)\n}\n\nBotCommand(command: String, description: String)\n **Official reference:** https://core.telegram.org/bots/api#botcommand\ncommand\n&lt;p&gt;Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and underscores.&lt;/p&gt;\n\ndescription\n&lt;p&gt;Description of the command; 1-256 characters.&lt;/p&gt;\n\nSynonyms:\ntelega/model.BotCommand\ntelega/model BotCommand","url":"telega/model.html#BotCommand"},{"doc":"telega/model","title":"BotCommandParameters","content":"pub type BotCommandParameters {\n  BotCommandParameters(\n    scope: Option(BotCommandScope),\n    language_code: Option(String),\n  )\n}\n\nBotCommandParameters(\n  scope: Option(BotCommandScope),\n  language_code: Option(String),\n)\n\nscope\n&lt;p&gt;An object, describing scope of users for which the commands are relevant. Defaults to &lt;code&gt;BotCommandScopeDefault&lt;/code&gt;.&lt;/p&gt;\n\nlanguage_code\n&lt;p&gt;A two-letter ISO 639-1 language code. If empty, commands will be applied to all users from the given scope, for whose language there are no dedicated commands&lt;/p&gt;\n\nSynonyms:\ntelega/model.BotCommandParameters\ntelega/model BotCommandParameters","url":"telega/model.html#BotCommandParameters"},{"doc":"telega/model","title":"BotCommandScope","content":"pub type BotCommandScope {\n  BotCommandDefaultScope\n  BotCommandAllPrivateChatsScope\n  BotCommandScopeAllGroupChats\n  BotCommandScopeAllChatAdministrators\n  BotCommandScopeChat(chat_id: Int)\n  BotCommandScopeChatString(chat_id: IntOrString)\n  BotCommandScopeChatAdministrators(chat_id: IntOrString)\n  BotCommandScopeChatMember(chat_id: IntOrString, user_id: Int)\n}\n **Official reference:** https://core.telegram.org/bots/api#botcommandscope\nBotCommandDefaultScope\n Represents the default scope of bot commands. Default commands are used if no commands with a narrower scope are specified for the user.\n\nBotCommandAllPrivateChatsScope\n Represents the scope of bot commands, covering all private chats.\n\nBotCommandScopeAllGroupChats\n Represents the scope of bot commands, covering all group and supergroup chats.\n\nBotCommandScopeAllChatAdministrators\n Represents the scope of bot commands, covering all group and supergroup chat administrators.\n\nBotCommandScopeChat(chat_id: Int)\n Represents the scope of bot commands, covering a specific chat.\nchat_id\n&lt;p&gt;Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)&lt;/p&gt;\n\nBotCommandScopeChatString(chat_id: IntOrString)\n Represents the scope of bot commands, covering a specific chat.\nchat_id\n&lt;p&gt;Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)&lt;/p&gt;\n\nBotCommandScopeChatAdministrators(chat_id: IntOrString)\n Represents the scope of bot commands, covering all administrators of a specific group or supergroup chat.\nchat_id\n&lt;p&gt;Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)&lt;/p&gt;\n\nBotCommandScopeChatMember(chat_id: IntOrString, user_id: Int)\n Represents the scope of bot commands, covering a specific member of a group or supergroup chat.\nchat_id\n&lt;p&gt;Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)&lt;/p&gt;\n\nuser_id\n&lt;p&gt;Unique identifier of the target user&lt;/p&gt;\n\nSynonyms:\ntelega/model.BotCommandScope\ntelega/model BotCommandScope","url":"telega/model.html#BotCommandScope"},{"doc":"telega/model","title":"CallbackQuery","content":"pub type CallbackQuery {\n  CallbackQuery(\n    id: String,\n    from: User,\n    message: Option(MaybeInaccessibleMessage),\n    inline_message_id: Option(String),\n    chat_instance: Option(String),\n    data: Option(String),\n    game_short_name: Option(String),\n  )\n}\n\nCallbackQuery(\n  id: String,\n  from: User,\n  message: Option(MaybeInaccessibleMessage),\n  inline_message_id: Option(String),\n  chat_instance: Option(String),\n  data: Option(String),\n  game_short_name: Option(String),\n)\n This object represents an incoming callback query from a callback button in an [inline keyboard](https://core.telegram.org/bots/features#inline-keyboards).\n If the button that originated the query was attached to a message sent by the bot, the field message will be present.\n If the button was attached to a message sent via the bot (in [inline mode](https://core.telegram.org/bots/api#inline-mode)), the field _inline_message_id_ will be present.\n Exactly one of the fields data or _game_short_name_ will be present.\n\n &gt; **NOTE:** After the user presses a callback button, Telegram clients will display a progress bar until you call [answerCallbackQuery](https://core.telegram.org/bots/api#answercallbackquery).\n &gt; It is, therefore, necessary to react by calling [answerCallbackQuery](https://core.telegram.org/bots/api#answercallbackquery) even if no notification to the user is needed (e.g., without specifying any of the optional parameters).\n\n **Official reference:** [CallbackQuery](https://core.telegram.org/bots/api#callbackquery)\nid\n&lt;p&gt;Unique identifier for this query&lt;/p&gt;\n\nfrom\n&lt;p&gt;Sender&lt;/p&gt;\n\nmessage\n&lt;p&gt;Message sent by the bot with the callback button that originated the query&lt;/p&gt;\n\ninline_message_id\n&lt;p&gt;Identifier of the message sent via the bot in inline mode, that originated the query.&lt;/p&gt;\n\nchat_instance\n&lt;p&gt;Global identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in &lt;a href=&quot;https://core.telegram.org/bots/api#games&quot;&gt;games&lt;/a&gt;.&lt;/p&gt;\n\ndata\n&lt;p&gt;Data associated with the callback button. Be aware that the message originated the query can contain no callback buttons with this data.&lt;/p&gt;\n\ngame_short_name\n&lt;p&gt;Short name of a &lt;a href=&quot;https://core.telegram.org/bots/api#games&quot;&gt;Game&lt;/a&gt; to be returned, serves as the unique identifier for the game&lt;/p&gt;\n\nSynonyms:\ntelega/model.CallbackQuery\ntelega/model CallbackQuery","url":"telega/model.html#CallbackQuery"},{"doc":"telega/model","title":"Chat","content":"pub type Chat {\n  Chat(\n    id: Int,\n    username: Option(String),\n    first_name: Option(String),\n    last_name: Option(String),\n    is_forum: Option(Bool),\n  )\n}\n\nChat(\n  id: Int,\n  username: Option(String),\n  first_name: Option(String),\n  last_name: Option(String),\n  is_forum: Option(Bool),\n)\n **Official reference:** https://core.telegram.org/bots/api#chat\nid\n&lt;p&gt;Unique identifier for this chat.&lt;/p&gt;\n\nusername\n&lt;p&gt;Username, for private chats, supergroups and channels if available&lt;/p&gt;\n\nfirst_name\n&lt;p&gt;First name of the other party in a private chat&lt;/p&gt;\n\nlast_name\n&lt;p&gt;Last name of the other party in a private chat&lt;/p&gt;\n\nis_forum\n&lt;p&gt;True, if the supergroup chat is a forum (has &lt;a href=&quot;https://telegram.org/blog/topics-in-groups-collectible-usernames#topics-in-groups&quot;&gt;topics&lt;/a&gt; enabled)&lt;/p&gt;\n\nSynonyms:\ntelega/model.Chat\ntelega/model Chat","url":"telega/model.html#Chat"},{"doc":"telega/model","title":"ChatAdministratorRights","content":"pub type ChatAdministratorRights {\n  ChatAdministratorRights(\n    is_anonymous: Bool,\n    can_manage_chat: Bool,\n    can_delete_messages: Bool,\n    can_manage_voice_chats: Bool,\n    can_restrict_members: Bool,\n    can_promote_members: Bool,\n    can_change_info: Bool,\n    can_invite_users: Bool,\n    can_post_stories: Bool,\n    can_edit_stories: Bool,\n    can_delete_stories: Bool,\n    can_post_messages: Option(Bool),\n    can_edit_messages: Option(Bool),\n    can_pin_messages: Option(Bool),\n    can_manage_topics: Option(Bool),\n  )\n}\n\nChatAdministratorRights(\n  is_anonymous: Bool,\n  can_manage_chat: Bool,\n  can_delete_messages: Bool,\n  can_manage_voice_chats: Bool,\n  can_restrict_members: Bool,\n  can_promote_members: Bool,\n  can_change_info: Bool,\n  can_invite_users: Bool,\n  can_post_stories: Bool,\n  can_edit_stories: Bool,\n  can_delete_stories: Bool,\n  can_post_messages: Option(Bool),\n  can_edit_messages: Option(Bool),\n  can_pin_messages: Option(Bool),\n  can_manage_topics: Option(Bool),\n)\n Represents the rights of an administrator in a chat.\n\n **Official reference:** [ChatAdministratorRights](https://core.telegram.org/bots/api#chatadministratorrights)\nis_anonymous\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the user’s presence in the chat is hidden&lt;/p&gt;\n\ncan_manage_chat\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can access the chat event log, get boost list, see hidden supergroup and channel members, report spam messages and ignore slow mode. Implied by any other administrator privilege.&lt;/p&gt;\n\ncan_delete_messages\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can delete messages of other users&lt;/p&gt;\n\ncan_manage_voice_chats\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can manage video chats&lt;/p&gt;\n\ncan_restrict_members\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can restrict, ban or unban chat members, or access supergroup statistics&lt;/p&gt;\n\ncan_promote_members\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can add new administrators with a subset of their own privileges or demote administrators that they have promoted, directly or indirectly (promoted by administrators that were appointed by the user)&lt;/p&gt;\n\ncan_change_info\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the user is allowed to change the chat title, photo and other settings&lt;/p&gt;\n\ncan_invite_users\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the user is allowed to invite new users to the chat&lt;/p&gt;\n\ncan_post_stories\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can post stories to the chat&lt;/p&gt;\n\ncan_edit_stories\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can edit stories posted by other users&lt;/p&gt;\n\ncan_delete_stories\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can delete stories posted by other users&lt;/p&gt;\n\ncan_post_messages\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can post messages in the channel, or access channel statistics; for channels only&lt;/p&gt;\n\ncan_edit_messages\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the administrator can edit messages of other users and can pin messages; for channels only&lt;/p&gt;\n\ncan_pin_messages\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the user is allowed to pin messages; for groups and supergroups only&lt;/p&gt;\n\ncan_manage_topics\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the user is allowed to create, rename, close, and reopen forum topics; for supergroups only&lt;/p&gt;\n\nSynonyms:\ntelega/model.ChatAdministratorRights\ntelega/model ChatAdministratorRights","url":"telega/model.html#ChatAdministratorRights"},{"doc":"telega/model","title":"EditMessageTextParameters","content":"pub type EditMessageTextParameters {\n  EditMessageTextParameters(\n    chat_id: Option(IntOrString),\n    message_id: Option(Int),\n    inline_message_id: Option(String),\n    text: String,\n    parse_mode: Option(String),\n    entities: Option(List(MessageEntity)),\n    link_preview_options: Option(LinkPreviewOptions),\n    reply_markup: Option(InlineKeyboardMarkup),\n  )\n}\n\nEditMessageTextParameters(\n  chat_id: Option(IntOrString),\n  message_id: Option(Int),\n  inline_message_id: Option(String),\n  text: String,\n  parse_mode: Option(String),\n  entities: Option(List(MessageEntity)),\n  link_preview_options: Option(LinkPreviewOptions),\n  reply_markup: Option(InlineKeyboardMarkup),\n)\n\nchat_id\n&lt;p&gt;Required if &lt;em&gt;inline_message_id&lt;/em&gt; is not specified.\nUnique identifier for the target chat or username of the target channel (in the format &lt;code&gt;@channelusername&lt;/code&gt;)&lt;/p&gt;\n\nmessage_id\n&lt;p&gt;Required if inline_message_id is not specified. Identifier of the message to edit&lt;/p&gt;\n\ninline_message_id\n&lt;p&gt;Required if &lt;em&gt;chat_id&lt;/em&gt; and &lt;em&gt;message_id&lt;/em&gt; are not specified. Identifier of the inline message&lt;/p&gt;\n\ntext\n&lt;p&gt;New text of the message, 1-4096 characters after entities parsing&lt;/p&gt;\n\nparse_mode\n&lt;p&gt;Mode for parsing entities in the message text. See &lt;a href=&quot;https://core.telegram.org/bots/api#formatting-options&quot;&gt;formatting options&lt;/a&gt; for more details.&lt;/p&gt;\n\nentities\n&lt;p&gt;A JSON-serialized list of special entities that appear in message text, which can be specified instead of &lt;em&gt;parse_mode&lt;/em&gt;&lt;/p&gt;\n\nlink_preview_options\n&lt;p&gt;Link preview generation options for the message&lt;/p&gt;\n\nreply_markup\n&lt;p&gt;A JSON-serialized object for an &lt;a href=&quot;https://core.telegram.org/bots/features#inline-keyboards&quot;&gt;inline keyboard&lt;/a&gt;.&lt;/p&gt;\n\nSynonyms:\ntelega/model.EditMessageTextParameters\ntelega/model EditMessageTextParameters","url":"telega/model.html#EditMessageTextParameters"},{"doc":"telega/model","title":"EditMessageTextResult","content":"pub type EditMessageTextResult {\n  EditMessageTextMessage(Message)\n  EditMessageTextBool(Bool)\n}\n\nEditMessageTextMessage(Message)\n\n\nEditMessageTextBool(Bool)\n\n\nSynonyms:\ntelega/model.EditMessageTextResult\ntelega/model EditMessageTextResult","url":"telega/model.html#EditMessageTextResult"},{"doc":"telega/model","title":"File","content":"pub type File {\n  File(\n    file_id: String,\n    file_unique_id: Option(String),\n    file_size: Option(Int),\n    file_path: Option(String),\n  )\n}\n https://core.telegram.org/bots/api#file\nFile(\n  file_id: String,\n  file_unique_id: Option(String),\n  file_size: Option(Int),\n  file_path: Option(String),\n)\n This object represents a file ready to be downloaded. The file can be downloaded via the link `https://api.telegram.org/file/bot&lt;token&gt;/&lt;file_path&gt;`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling [getFile](https://core.telegram.org/bots/api#getfile).\n\n **Official reference:** [File](https://core.telegram.org/bots/api#file)\nfile_id\n&lt;p&gt;Unique identifier for this file&lt;/p&gt;\n\nfile_unique_id\n&lt;p&gt;&lt;em&gt;Optional&lt;/em&gt;. Unique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file&lt;/p&gt;\n\nfile_size\n&lt;p&gt;&lt;em&gt;Optional&lt;/em&gt;. File size, if known&lt;/p&gt;\n\nfile_path\n&lt;p&gt;&lt;em&gt;Optional&lt;/em&gt;. File path. Use &lt;code&gt;https://api.telegram.org/file/bot&amp;lt;token&amp;gt;/&amp;lt;file_path&amp;gt;&lt;/code&gt; to get the file&lt;/p&gt;\n\nSynonyms:\ntelega/model.File\ntelega/model File","url":"telega/model.html#File"},{"doc":"telega/model","title":"ForwardMessageParameters","content":"pub type ForwardMessageParameters {\n  ForwardMessageParameters(\n    chat_id: IntOrString,\n    from_chat_id: IntOrString,\n    message_id: Int,\n    disable_notification: Option(Bool),\n    message_thread_id: Option(Int),\n    protect_content: Option(Bool),\n  )\n}\n\nForwardMessageParameters(\n  chat_id: IntOrString,\n  from_chat_id: IntOrString,\n  message_id: Int,\n  disable_notification: Option(Bool),\n  message_thread_id: Option(Int),\n  protect_content: Option(Bool),\n)\n\nchat_id\n&lt;p&gt;Unique identifier for the target chat or username of the target channel (in the format &lt;code&gt;@channelusername&lt;/code&gt;)&lt;/p&gt;\n\nfrom_chat_id\n&lt;p&gt;Unique identifier for the chat where the original message was sent (or channel username in the format &lt;code&gt;@channelusername&lt;/code&gt;)&lt;/p&gt;\n\nmessage_id\n&lt;p&gt;Message identifier in the chat specified in &lt;em&gt;from_chat_id&lt;/em&gt;&lt;/p&gt;\n\ndisable_notification\n&lt;p&gt;Sends the message silently. Users will receive a notification with no sound.&lt;/p&gt;\n\nmessage_thread_id\n&lt;p&gt;Unique identifier for the target message thread (topic) of the forum; for forum supergroups only&lt;/p&gt;\n\nprotect_content\n&lt;p&gt;Protects the contents of the forwarded message from forwarding and saving&lt;/p&gt;\n\nSynonyms:\ntelega/model.ForwardMessageParameters\ntelega/model ForwardMessageParameters","url":"telega/model.html#ForwardMessageParameters"},{"doc":"telega/model","title":"InaccessibleMessage","content":"pub type InaccessibleMessage {\n  InaccessibleMessage(chat: Chat, message_id: Int, date: Int)\n}\n\nInaccessibleMessage(chat: Chat, message_id: Int, date: Int)\n This object describes a message that was deleted or is otherwise inaccessible to the bot.\n\n **Official reference:** [InaccessibleMessage](https://core.telegram.org/bots/api#inaccessiblemessage)\nchat\n&lt;p&gt;Chat the message belonged to&lt;/p&gt;\n\nmessage_id\n&lt;p&gt;Unique message identifier inside the chat&lt;/p&gt;\n\ndate\n&lt;p&gt;Always 0. The field can be used to differentiate regular and inaccessible messages.&lt;/p&gt;\n\nSynonyms:\ntelega/model.InaccessibleMessage\ntelega/model InaccessibleMessage","url":"telega/model.html#InaccessibleMessage"},{"doc":"telega/model","title":"InlineKeyboardButton","content":"pub type InlineKeyboardButton {\n  InlineKeyboardButton(\n    text: String,\n    url: Option(String),\n    callback_data: Option(String),\n    web_app: Option(WebAppInfo),\n    login_url: Option(LoginUrl),\n    switch_inline_query: Option(String),\n    switch_inline_query_current_chat: Option(String),\n    switch_inline_query_chosen_chat: Option(\n      SwitchInlineQueryChosenChat,\n    ),\n    pay: Option(Bool),\n  )\n}\n\nInlineKeyboardButton(\n  text: String,\n  url: Option(String),\n  callback_data: Option(String),\n  web_app: Option(WebAppInfo),\n  login_url: Option(LoginUrl),\n  switch_inline_query: Option(String),\n  switch_inline_query_current_chat: Option(String),\n  switch_inline_query_chosen_chat: Option(\n    SwitchInlineQueryChosenChat,\n  ),\n  pay: Option(Bool),\n)\n **Official reference:** https://core.telegram.org/bots/api#inlinekeyboardbutton\ntext\n&lt;p&gt;Label text on the button&lt;/p&gt;\n\nurl\n&lt;p&gt;HTTP or &lt;code&gt;tg://&lt;/code&gt; URL to be opened when the button is pressed. Links &lt;code&gt;tg://user?id=&amp;lt;user_id&amp;gt;&lt;/code&gt; can be used to mention a user by their identifier without using a username, if this is allowed by their privacy settings.&lt;/p&gt;\n\ncallback_data\n&lt;p&gt;Data to be sent in a &lt;a href=&quot;https://core.telegram.org/bots/api#callbackquery&quot;&gt;callback query&lt;/a&gt; to the bot when button is pressed, 1-64 bytes&lt;/p&gt;\n\nweb_app\n&lt;p&gt;Description of the &lt;a href=&quot;https://core.telegram.org/bots/webapps&quot;&gt;Web App&lt;/a&gt; that will be launched when the user presses the button. The Web App will be able to send an arbitrary message on behalf of the user using the method &lt;a href=&quot;https://core.telegram.org/bots/api#answerwebappquery&quot;&gt;answerWebAppQuery&lt;/a&gt;. Available only in private chats between a user and the bot.&lt;/p&gt;\n\nlogin_url\n&lt;p&gt;An HTTPS URL used to automatically authorize the user. Can be used as a replacement for the &lt;a href=&quot;https://core.telegram.org/widgets/login&quot;&gt;Telegram Login Widget&lt;/a&gt;.&lt;/p&gt;\n\nswitch_inline_query\n&lt;p&gt;If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot’s username and the specified inline query in the input field. May be empty, in which case just the bot’s username will be inserted.&lt;/p&gt;\n\nswitch_inline_query_current_chat\n&lt;p&gt;set, pressing the button will insert the bot’s username and the specified inline query in the current chat’s input field. May be empty, in which case only the bot’s username will be inserted.&lt;/p&gt;\n&lt;p&gt;This offers a quick way for the user to open your bot in inline mode in the same chat - good for selecting something from multiple options.&lt;/p&gt;\n\nswitch_inline_query_chosen_chat\n&lt;p&gt;If set, pressing the button will prompt the user to select one of their chats of the specified type, open that chat and insert the bot’s username and the specified inline query in the input field&lt;/p&gt;\n\npay\n&lt;p&gt;Specify True, to send a &lt;a href=&quot;https://core.telegram.org/bots/api#payments&quot;&gt;Pay button&lt;/a&gt;.&lt;/p&gt;\n&lt;p&gt;&lt;strong&gt;NOTE&lt;/strong&gt;: This type of button &lt;strong&gt;must&lt;/strong&gt; always be the first button in the first row and can only be used in invoice messages.&lt;/p&gt;\n\nSynonyms:\ntelega/model.InlineKeyboardButton\ntelega/model InlineKeyboardButton","url":"telega/model.html#InlineKeyboardButton"},{"doc":"telega/model","title":"InlineKeyboardMarkup","content":"pub type InlineKeyboardMarkup {\n  InlineKeyboardMarkup(\n    inline_keyboard: List(List(InlineKeyboardButton)),\n  )\n}\n\nInlineKeyboardMarkup(\n  inline_keyboard: List(List(InlineKeyboardButton)),\n)\n **Official reference:** https://core.telegram.org/bots/api#inlinekeyboardmarkup\n\nSynonyms:\ntelega/model.InlineKeyboardMarkup\ntelega/model InlineKeyboardMarkup","url":"telega/model.html#InlineKeyboardMarkup"},{"doc":"telega/model","title":"IntOrString","content":"pub type IntOrString {\n  Inted(Int)\n  Stringed(String)\n}\n\nInted(Int)\n\n\nStringed(String)\n\n\nSynonyms:\ntelega/model.IntOrString\ntelega/model IntOrString","url":"telega/model.html#IntOrString"},{"doc":"telega/model","title":"KeyboardButton","content":"pub type KeyboardButton {\n  KeyboardButton(\n    text: String,\n    request_users: Option(KeyboardButtonRequestUsers),\n    request_chat: Option(KeyboardButtonRequestChat),\n    request_contact: Option(Bool),\n    request_location: Option(Bool),\n    request_poll: Option(KeyboardButtonPollType),\n    web_app: Option(WebAppInfo),\n  )\n}\n\nKeyboardButton(\n  text: String,\n  request_users: Option(KeyboardButtonRequestUsers),\n  request_chat: Option(KeyboardButtonRequestChat),\n  request_contact: Option(Bool),\n  request_location: Option(Bool),\n  request_poll: Option(KeyboardButtonPollType),\n  web_app: Option(WebAppInfo),\n)\n This object represents one button of the reply keyboard. For simple text buttons, String can be used instead of this object to specify the button text. The optional fields _web_app_, _request_users_, _request_chat_, _request_contact_, _request_location_, and _request_poll_ are mutually exclusive.\n\n **Official reference:** https://core.telegram.org/bots/api#keyboardbutton\ntext\n&lt;p&gt;Text of the button. If none of the optional fields are used, it will be sent as a message when the button is pressed&lt;/p&gt;\n\nrequest_users\n&lt;p&gt;If specified, pressing the button will open a list of suitable users. Identifiers of selected users will be sent to the bot in a “users_shared” service message. Available in private chats only.&lt;/p&gt;\n\nrequest_chat\n&lt;p&gt;If specified, pressing the button will open a list of suitable chats. Tapping on a chat will send its identifier to the bot in a “chat_shared” service message. Available in private chats only.&lt;/p&gt;\n\nrequest_contact\n&lt;p&gt;If &lt;em&gt;True&lt;/em&gt;, the user’s phone number will be sent as a contact when the button is pressed. Available in private chats only.&lt;/p&gt;\n\nrequest_location\n&lt;p&gt;If &lt;em&gt;True&lt;/em&gt;, the user’s current location will be sent when the button is pressed. Available in private chats only.&lt;/p&gt;\n\nrequest_poll\n&lt;p&gt;If specified, the user will be asked to create a poll and send it to the bot when the button is pressed. Available in private chats only.&lt;/p&gt;\n\nweb_app\n&lt;p&gt;If specified, the described &lt;a href=&quot;https://core.telegram.org/bots/webapps&quot;&gt;Web App&lt;/a&gt; will be launched when the button is pressed. The Web App will be able to send a “web_app_data” service message. Available in private chats only.&lt;/p&gt;\n\nSynonyms:\ntelega/model.KeyboardButton\ntelega/model KeyboardButton","url":"telega/model.html#KeyboardButton"},{"doc":"telega/model","title":"KeyboardButtonPollType","content":"pub type KeyboardButtonPollType {\n  KeyboardButtonPollType(poll_type: Option(String))\n}\n\nKeyboardButtonPollType(poll_type: Option(String))\n This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.\n\n **Official reference:** https://core.telegram.org/bots/api#keyboardbuttonpolltype\npoll_type\n&lt;p&gt;If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.&lt;/p&gt;\n&lt;p&gt;&lt;strong&gt;Official reference:&lt;/strong&gt; https://core.telegram.org/bots/api#polltype&lt;/p&gt;\n&lt;p&gt;&lt;strong&gt;Note&lt;/strong&gt;: This type is a wrapper around the official type. The official field name is &lt;code&gt;type&lt;/code&gt;.&lt;/p&gt;\n\nSynonyms:\ntelega/model.KeyboardButtonPollType\ntelega/model KeyboardButtonPollType","url":"telega/model.html#KeyboardButtonPollType"},{"doc":"telega/model","title":"KeyboardButtonRequestChat","content":"pub type KeyboardButtonRequestChat {\n  KeyboardButtonRequestChat(\n    request_id: Int,\n    chat_is_channel: Bool,\n    chat_is_forum: Option(Bool),\n    chat_has_username: Option(Bool),\n    chat_is_created: Option(Bool),\n    user_administrator_rights: Option(ChatAdministratorRights),\n    bot_administrator_rights: Option(ChatAdministratorRights),\n    bot_is_member: Option(Bool),\n    request_title: Option(Bool),\n    request_username: Option(Bool),\n    request_photo: Option(Bool),\n  )\n}\n\nKeyboardButtonRequestChat(\n  request_id: Int,\n  chat_is_channel: Bool,\n  chat_is_forum: Option(Bool),\n  chat_has_username: Option(Bool),\n  chat_is_created: Option(Bool),\n  user_administrator_rights: Option(ChatAdministratorRights),\n  bot_administrator_rights: Option(ChatAdministratorRights),\n  bot_is_member: Option(Bool),\n  request_title: Option(Bool),\n  request_username: Option(Bool),\n  request_photo: Option(Bool),\n)\n This object defines the criteria used to request a suitable chat. Information about the selected chat will be shared with the bot when the corresponding button is pressed. The bot will be granted requested rights in the сhat if appropriate\n\n [More about requesting chats](https://core.telegram.org/bots/features#chat-and-user-selection).\n\n **Official reference:** https://core.telegram.org/bots/api#keyboardbuttonrequestchat\nrequest_id\n&lt;p&gt;Signed 32-bit identifier of the request, which will be received back in the &lt;a href=&quot;https://core.telegram.org/bots/api#chatshared&quot;&gt;ChatShared&lt;/a&gt; object. Must be unique within the message&lt;/p&gt;\n\nchat_is_channel\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request a channel chat, pass &lt;em&gt;False&lt;/em&gt; to request a group or a supergroup chat.&lt;/p&gt;\n\nchat_is_forum\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request a forum supergroup, pass &lt;em&gt;False&lt;/em&gt; to request a non-forum chat. If not specified, no additional restrictions are applied.&lt;/p&gt;\n\nchat_has_username\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request a supergroup or a channel with a username, pass &lt;em&gt;False&lt;/em&gt; to request a chat without a username. If not specified, no additional restrictions are applied.&lt;/p&gt;\n\nchat_is_created\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request a chat owned by the user. Otherwise, no additional restrictions are applied.&lt;/p&gt;\n\nuser_administrator_rights\n&lt;p&gt;A JSON-serialized object listing the required administrator rights of the user in the chat. The rights must be a superset of &lt;em&gt;bot_administrator_rights&lt;/em&gt;. If not specified, no additional restrictions are applied.&lt;/p&gt;\n\nbot_administrator_rights\n&lt;p&gt;A JSON-serialized object listing the required administrator rights of the bot in the chat. The rights must be a subset of &lt;em&gt;user_administrator_rights&lt;/em&gt;. If not specified, no additional restrictions are applied.&lt;/p&gt;\n\nbot_is_member\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request a chat with the bot as a member. Otherwise, no additional restrictions are applied.&lt;/p&gt;\n\nrequest_title\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the chat’s title&lt;/p&gt;\n\nrequest_username\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the chat’s username&lt;/p&gt;\n\nrequest_photo\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the chat’s photo&lt;/p&gt;\n\nSynonyms:\ntelega/model.KeyboardButtonRequestChat\ntelega/model KeyboardButtonRequestChat","url":"telega/model.html#KeyboardButtonRequestChat"},{"doc":"telega/model","title":"KeyboardButtonRequestUsers","content":"pub type KeyboardButtonRequestUsers {\n  KeyboardButtonRequestUsers(\n    request_id: Int,\n    user_is_bot: Option(Bool),\n    user_is_premium: Option(Bool),\n    max_quantity: Option(Int),\n    request_name: Option(Bool),\n    request_username: Option(Bool),\n    request_photo: Option(Bool),\n  )\n}\n\nKeyboardButtonRequestUsers(\n  request_id: Int,\n  user_is_bot: Option(Bool),\n  user_is_premium: Option(Bool),\n  max_quantity: Option(Int),\n  request_name: Option(Bool),\n  request_username: Option(Bool),\n  request_photo: Option(Bool),\n)\n This object defines the criteria used to request suitable users. Information about the selected users will be shared with the bot when the corresponding button is pressed.\n\n [More about requesting users](https://core.telegram.org/bots/features#chat-and-user-selection).\n\n **Official reference:** https://core.telegram.org/bots/api#keyboardbuttonrequestusers\nrequest_id\n&lt;p&gt;Signed 32-bit identifier of the request that will be received back in the &lt;a href=&quot;https://core.telegram.org/bots/api#usersshared&quot;&gt;UsersShared&lt;/a&gt; object. Must be unique within the message&lt;/p&gt;\n\nuser_is_bot\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request bots, pass &lt;em&gt;False&lt;/em&gt; to request regular users. If not specified, no additional restrictions are applied.&lt;/p&gt;\n\nuser_is_premium\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request premium users, pass &lt;em&gt;False&lt;/em&gt; to request non-premium users. If not specified, no additional restrictions are applied.&lt;/p&gt;\n\nmax_quantity\n&lt;p&gt;The maximum number of users to be selected; 1-10. Defaults to 1.&lt;/p&gt;\n\nrequest_name\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the users’ first and last name&lt;/p&gt;\n\nrequest_username\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the users’ username&lt;/p&gt;\n\nrequest_photo\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the users’ photo&lt;/p&gt;\n\nSynonyms:\ntelega/model.KeyboardButtonRequestUsers\ntelega/model KeyboardButtonRequestUsers","url":"telega/model.html#KeyboardButtonRequestUsers"},{"doc":"telega/model","title":"LinkPreviewOptions","content":"pub type LinkPreviewOptions {\n  LinkPreviewOptions(\n    is_disabled: Option(Bool),\n    url: Option(String),\n    prefer_small_media: Option(Bool),\n    prefer_large_media: Option(Bool),\n    show_above_text: Option(Bool),\n  )\n}\n\nLinkPreviewOptions(\n  is_disabled: Option(Bool),\n  url: Option(String),\n  prefer_small_media: Option(Bool),\n  prefer_large_media: Option(Bool),\n  show_above_text: Option(Bool),\n)\n Describes the options used for link preview generation.\n\n **Official reference:** [LinkPreviewOptions](https://core.telegram.org/bots/api#linkpreviewoptions)\nis_disabled\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the link preview is disabled&lt;/p&gt;\n\nurl\n&lt;p&gt;URL to use for the link preview. If empty, then the first URL found in the message text will be used&lt;/p&gt;\n\nprefer_small_media\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the media in the link preview is supposed to be shrunk; ignored if the URL isn’t explicitly specified or media size change isn’t supported for the preview&lt;/p&gt;\n\nprefer_large_media\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the media in the link preview is supposed to be enlarged; ignored if the URL isn’t explicitly specified or media size change isn’t supported for the preview&lt;/p&gt;\n\nshow_above_text\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the link preview must be shown above the message text; otherwise, the link preview will be shown below the message text&lt;/p&gt;\n\nSynonyms:\ntelega/model.LinkPreviewOptions\ntelega/model LinkPreviewOptions","url":"telega/model.html#LinkPreviewOptions"},{"doc":"telega/model","title":"LoginUrl","content":"pub type LoginUrl {\n  LoginUrl(\n    url: String,\n    forward_text: Option(String),\n    bot_username: Option(String),\n    request_write_access: Option(Bool),\n  )\n}\n\nLoginUrl(\n  url: String,\n  forward_text: Option(String),\n  bot_username: Option(String),\n  request_write_access: Option(Bool),\n)\n This object represents a parameter of the inline keyboard button used to automatically authorize a user. Serves as a great replacement for the [Telegram Login Widget](https://core.telegram.org/widgets/login) when the user is coming from Telegram. All the user needs to do is tap/click a button and confirm that they want to log in.\nurl\n&lt;p&gt;An HTTPS URL to be opened with user authorization data added to the query string when the button is pressed. If the user refuses to provide authorization data, the original URL without information about the user will be opened. The data added is the same as described in &lt;a href=&quot;https://core.telegram.org/widgets/login#receiving-authorization-data&quot;&gt;Receiving authorization data&lt;/a&gt;.&lt;/p&gt;\n&lt;p&gt;NOTE: You must always check the hash of the received data to verify the authentication and the integrity of the data as described in &lt;a href=&quot;https://core.telegram.org/widgets/login#checking-authorization&quot;&gt;Checking authorization&lt;/a&gt;.&lt;/p&gt;\n\nforward_text\n&lt;p&gt;New text of the button in forwarded messages.&lt;/p&gt;\n\nbot_username\n&lt;p&gt;Username of a bot, which will be used for user authorization. &lt;a href=&quot;https://core.telegram.org/widgets/login#setting-up-a-bot&quot;&gt;See Setting up a bot&lt;/a&gt; for more details. If not specified, the current bot’s username will be assumed. The url’s domain must be the same as the domain linked with the bot. See &lt;a href=&quot;https://core.telegram.org/widgets/login#linking-your-domain-to-the-bot&quot;&gt;Linking your domain to the bot&lt;/a&gt; for more details.&lt;/p&gt;\n\nrequest_write_access\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to request the permission for your bot to send messages to the user.&lt;/p&gt;\n\nSynonyms:\ntelega/model.LoginUrl\ntelega/model LoginUrl","url":"telega/model.html#LoginUrl"},{"doc":"telega/model","title":"MaybeInaccessibleMessage","content":"pub type MaybeInaccessibleMessage {\n  MaybeInaccessibleMessageMessage(Message)\n  MaybeInaccessibleMessageInaccessible(InaccessibleMessage)\n}\n This object describes a message that can be inaccessible to the bot.\n\n **Official reference:** [MaybeInaccessibleMessage](https://core.telegram.org/bots/api#maybeinaccessiblemessage)\nMaybeInaccessibleMessageMessage(Message)\n\n\nMaybeInaccessibleMessageInaccessible(InaccessibleMessage)\n\n\nSynonyms:\ntelega/model.MaybeInaccessibleMessage\ntelega/model MaybeInaccessibleMessage","url":"telega/model.html#MaybeInaccessibleMessage"},{"doc":"telega/model","title":"MenuButton","content":"pub type MenuButton {\n  MenuButtonCommands(button_type: String)\n  MenuButtonWebApp(button_type: String, web_app: WebAppInfo)\n  MenuButtonDefault(button_type: String)\n}\n Describes the bot&#39;s menu button in a private chat.\n\n **Official reference:** https://core.telegram.org/bots/api#menubutton\nMenuButtonCommands(button_type: String)\n Represents a menu button, which opens the bot&#39;s list of commands\nbutton_type\n&lt;p&gt;Type of the button, must be &lt;code&gt;commands&lt;/code&gt;&lt;/p&gt;\n\nMenuButtonWebApp(button_type: String, web_app: WebAppInfo)\n Represents a menu button, which launches a Web App.\nbutton_type\n&lt;p&gt;Type of the button, must be &lt;code&gt;web_app&lt;/code&gt;&lt;/p&gt;\n\nweb_app\n&lt;p&gt;Information about the Web App&lt;/p&gt;\n\nMenuButtonDefault(button_type: String)\n Describes that no specific value for the menu button was set.\nbutton_type\n&lt;p&gt;Type of the button, must be &lt;code&gt;default&lt;/code&gt;&lt;/p&gt;\n\nSynonyms:\ntelega/model.MenuButton\ntelega/model MenuButton","url":"telega/model.html#MenuButton"},{"doc":"telega/model","title":"Message","content":"pub type Message {\n  Message(\n    message_id: Int,\n    message_thread_id: Option(Int),\n    from: Option(User),\n    sender_chat: Option(Chat),\n    sender_boost_count: Option(Int),\n    date: Int,\n    chat: Chat,\n    is_topic_message: Option(Bool),\n    is_automatic_forward: Option(Bool),\n    reply_to_message: Option(Message),\n    via_bot: Option(User),\n    edit_date: Option(Int),\n    has_protected_content: Option(Bool),\n    is_from_offline: Option(Bool),\n    media_group_id: Option(String),\n    author_signature: Option(String),\n    text: Option(String),\n    entities: Option(List(MessageEntity)),\n    caption: Option(String),\n    caption_entities: Option(List(MessageEntity)),\n    has_media_spoiler: Option(Bool),\n    new_chat_members: Option(List(User)),\n    left_chat_member: Option(User),\n    new_chat_title: Option(String),\n    delete_chat_photo: Option(Bool),\n    group_chat_created: Option(Bool),\n    supergroup_chat_created: Option(Bool),\n    channel_chat_created: Option(Bool),\n    migrate_to_chat_id: Option(Int),\n    migrate_from_chat_id: Option(Int),\n    connected_website: Option(String),\n    web_app_data: Option(WebAppData),\n    reply_markup: Option(InlineKeyboardMarkup),\n  )\n}\n\nMessage(\n  message_id: Int,\n  message_thread_id: Option(Int),\n  from: Option(User),\n  sender_chat: Option(Chat),\n  sender_boost_count: Option(Int),\n  date: Int,\n  chat: Chat,\n  is_topic_message: Option(Bool),\n  is_automatic_forward: Option(Bool),\n  reply_to_message: Option(Message),\n  via_bot: Option(User),\n  edit_date: Option(Int),\n  has_protected_content: Option(Bool),\n  is_from_offline: Option(Bool),\n  media_group_id: Option(String),\n  author_signature: Option(String),\n  text: Option(String),\n  entities: Option(List(MessageEntity)),\n  caption: Option(String),\n  caption_entities: Option(List(MessageEntity)),\n  has_media_spoiler: Option(Bool),\n  new_chat_members: Option(List(User)),\n  left_chat_member: Option(User),\n  new_chat_title: Option(String),\n  delete_chat_photo: Option(Bool),\n  group_chat_created: Option(Bool),\n  supergroup_chat_created: Option(Bool),\n  channel_chat_created: Option(Bool),\n  migrate_to_chat_id: Option(Int),\n  migrate_from_chat_id: Option(Int),\n  connected_website: Option(String),\n  web_app_data: Option(WebAppData),\n  reply_markup: Option(InlineKeyboardMarkup),\n)\n **Official reference:** https://core.telegram.org/bots/api#message\nmessage_id\n&lt;p&gt;Unique message identifier inside this chat&lt;/p&gt;\n\nmessage_thread_id\n&lt;p&gt;Unique identifier of a message thread to which the message belongs; for supergroups only&lt;/p&gt;\n\nfrom\n&lt;p&gt;Sender of the message; empty for messages sent to channels. For backward compatibility, the field contains a fake sender user in non-channel chats, if the message was sent on behalf of a chat.&lt;/p&gt;\n\nsender_chat\n&lt;p&gt;Sender of the message, sent on behalf of a chat. For example, the channel itself for channel posts, the supergroup itself for messages from anonymous group administrators, the linked channel for messages automatically forwarded to the discussion group. For backward compatibility, the field &lt;em&gt;from&lt;/em&gt; contains a fake sender user in non-channel chats, if the message was sent on behalf of a chat.&lt;/p&gt;\n\nsender_boost_count\n&lt;p&gt;If the sender of the message boosted the chat, the number of boosts added by the user&lt;/p&gt;\n\ndate\n&lt;p&gt;Date the message was sent in Unix time. It is always a positive number, representing a valid date.&lt;/p&gt;\n\nchat\n&lt;p&gt;Chat the message belongs to&lt;/p&gt;\n\nis_topic_message\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the message is sent to a forum topic&lt;/p&gt;\n\nis_automatic_forward\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the message is a channel post that was automatically forwarded to the connected discussion group&lt;/p&gt;\n\nreply_to_message\n&lt;p&gt;For replies in the same chat and message thread, the original message. Note that the Message object in this field will not contain further &lt;em&gt;reply_to_message&lt;/em&gt; fields even if it itself is a reply.&lt;/p&gt;\n\nedit_date\n&lt;p&gt;Date the message was last edited in Unix time&lt;/p&gt;\n\nhas_protected_content\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the message can’t be forwarded&lt;/p&gt;\n\nis_from_offline\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the message was sent by an implicit action, for example, as an away or a greeting business message, or as a scheduled message&lt;/p&gt;\n\nmedia_group_id\n&lt;p&gt;The unique identifier of a media message group this message belongs to&lt;/p&gt;\n\nauthor_signature\n&lt;p&gt;Signature of the post author for messages in channels, or the custom title of an anonymous group administrator&lt;/p&gt;\n\ntext\n&lt;p&gt;For text messages, the actual UTF-8 text of the message&lt;/p&gt;\n\nentities\n&lt;p&gt;For text messages, special entities like usernames, URLs, bot commands, etc. that appear in the text&lt;/p&gt;\n\ncaption_entities\n&lt;p&gt;For messages with a caption, special entities like usernames, URLs, bot commands, etc. that appear in the caption&lt;/p&gt;\n\nhas_media_spoiler\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if the message media is covered by a spoiler animation&lt;/p&gt;\n\nnew_chat_members\n&lt;p&gt;New members that were added to the group or supergroup and information about them (the bot itself may be one of these members)&lt;/p&gt;\n\nleft_chat_member\n&lt;p&gt;A member was removed from the group, information about them (this member may be the bot itself)&lt;/p&gt;\n\nnew_chat_title\n&lt;p&gt;A chat title was changed to this value&lt;/p&gt;\n\ndelete_chat_photo\n&lt;p&gt;Service message: the chat photo was deleted&lt;/p&gt;\n\ngroup_chat_created\n&lt;p&gt;Service message: the group has been created&lt;/p&gt;\n\nsupergroup_chat_created\n&lt;p&gt;Service message: the supergroup has been created. This field can’t be received in a message coming through updates, because bot can’t be a member of a supergroup when it is created. It can only be found in reply_to_message if someone replies to a very first message in a directly created supergroup.&lt;/p&gt;\n\nchannel_chat_created\n&lt;p&gt;Service message: the channel has been created. This field can’t be received in a message coming through updates, because bot can’t be a member of a channel when it is created. It can only be found in reply_to_message if someone replies to a very first message in a channel.&lt;/p&gt;\n\nmigrate_to_chat_id\n&lt;p&gt;The group has been migrated to a supergroup with the specified identifier.&lt;/p&gt;\n\nmigrate_from_chat_id\n&lt;p&gt;The supergroup has been migrated from a group with the specified identifier.&lt;/p&gt;\n\nconnected_website\n&lt;p&gt;The domain name of the website on which the user has logged in. &lt;a href=&quot;https://core.telegram.org/widgets/login&quot;&gt;More about Telegram Login &amp;gt;&amp;gt;&lt;/a&gt;&lt;/p&gt;\n\nreply_markup\n&lt;p&gt;Inline keyboard attached to the message. &lt;code&gt;login_url&lt;/code&gt; buttons are represented as ordinary &lt;code&gt;url&lt;/code&gt; buttons.&lt;/p&gt;\n\nSynonyms:\ntelega/model.Message\ntelega/model Message","url":"telega/model.html#Message"},{"doc":"telega/model","title":"MessageEntity","content":"pub type MessageEntity {\n  MessageEntity(\n    entity_type: String,\n    offset: Int,\n    length: Int,\n    url: Option(String),\n    user: Option(User),\n    language: Option(String),\n    custom_emoji_id: Option(String),\n  )\n}\n\nMessageEntity(\n  entity_type: String,\n  offset: Int,\n  length: Int,\n  url: Option(String),\n  user: Option(User),\n  language: Option(String),\n  custom_emoji_id: Option(String),\n)\n **Official reference:** https://core.telegram.org/bots/api#messageentity\nentity_type\n&lt;p&gt;Type of the entity. Currently, can be “mention” (&lt;code&gt;@username&lt;/code&gt;), “hashtag” (&lt;code&gt;#hashtag&lt;/code&gt;), “cashtag” (&lt;code&gt;$USD&lt;/code&gt;), “bot_command” (&lt;code&gt;/start@jobs_bot&lt;/code&gt;), “url” (&lt;code&gt;https://telegram.org&lt;/code&gt;), “email” (&lt;code&gt;do-not-reply@telegram.org&lt;/code&gt;), “phone_number” (&lt;code&gt;+1-212-555-0123&lt;/code&gt;), “bold” (&lt;strong&gt;bold text&lt;/strong&gt;), “italic” (&lt;em&gt;italic text&lt;/em&gt;), “underline” (underlined text), “strikethrough” (strikethrough text), “spoiler” (spoiler message), “blockquote” (block quotation), “code” (monowidth string), “pre” (monowidth block), “text_link” (for clickable text URLs), “text_mention” (for users &lt;a href=&quot;https://telegram.org/blog/edit#new-mentions&quot;&gt;without usernames&lt;/a&gt;), “custom_emoji” (for inline custom emoji stickers)&lt;/p&gt;\n\noffset\n&lt;p&gt;Offset in &lt;a href=&quot;https://core.telegram.org/api/entities#entity-length&quot;&gt;UTF-16 code units&lt;/a&gt; to the start of the entity&lt;/p&gt;\n\nlength\n&lt;p&gt;Length of the entity in &lt;a href=&quot;https://core.telegram.org/api/entities#entity-length&quot;&gt;UTF-16 code units&lt;/a&gt;&lt;/p&gt;\n\nurl\n&lt;p&gt;For “text_link” only, URL that will be opened after user taps on the text&lt;/p&gt;\n\nuser\n&lt;p&gt;For “text_mention” only, the mentioned user&lt;/p&gt;\n\nlanguage\n&lt;p&gt;For “pre” only, the programming language of the entity text&lt;/p&gt;\n\ncustom_emoji_id\n&lt;p&gt;For “custom_emoji” only, unique identifier of the custom emoji. Use &lt;a href=&quot;https://core.telegram.org/bots/api#getcustomemojistickers&quot;&gt;getCustomEmojiStickers&lt;/a&gt; to get full information about the sticker&lt;/p&gt;\n\nSynonyms:\ntelega/model.MessageEntity\ntelega/model MessageEntity","url":"telega/model.html#MessageEntity"},{"doc":"telega/model","title":"ReplyMarkup","content":"pub type ReplyMarkup {\n  ReplyInlineKeyboardMarkup(\n    inline_keyboard: List(List(InlineKeyboardButton)),\n  )\n  ReplyKeyboardMarkup(\n    keyboard: List(List(KeyboardButton)),\n    is_persistent: Option(Bool),\n    resize_keyboard: Option(Bool),\n    one_time_keyboard: Option(Bool),\n    input_field_placeholder: Option(String),\n    selective: Option(Bool),\n  )\n  ReplyKeyboardRemove(\n    remove_keyboard: Bool,\n    selective: Option(Bool),\n  )\n  ForceReply(\n    force_reply: Bool,\n    input_field_placeholder: String,\n    selective: Bool,\n  )\n}\n\nReplyInlineKeyboardMarkup(\n  inline_keyboard: List(List(InlineKeyboardButton)),\n)\n This object represents an inline keyboard that appears right next to the message it belongs to.\n\n **Official reference:** https://core.telegram.org/bots/api#inlinekeyboardmarkup\ninline_keyboard\n&lt;p&gt;List of button rows, each represented by an List of &lt;a href=&quot;https://core.telegram.org/bots/api#inlinekeyboardbutton&quot;&gt;InlineKeyboardButton&lt;/a&gt; objects&lt;/p&gt;\n\nReplyKeyboardMarkup(\n  keyboard: List(List(KeyboardButton)),\n  is_persistent: Option(Bool),\n  resize_keyboard: Option(Bool),\n  one_time_keyboard: Option(Bool),\n  input_field_placeholder: Option(String),\n  selective: Option(Bool),\n)\n This object represents a [custom keyboard](https://core.telegram.org/bots/features#keyboards) with reply options (see [Introduction to bots](https://core.telegram.org/bots/features#keyboards) for details and examples).\n\n **Official reference:** https://core.telegram.org/bots/api#replykeyboardmarkup\nkeyboard\n&lt;p&gt;Array of button rows, each represented by an Array of &lt;a href=&quot;https://core.telegram.org/bots/api#keyboardbutton&quot;&gt;KeyboardButton&lt;/a&gt; objects&lt;/p&gt;\n\nis_persistent\n&lt;p&gt;Requests clients to always show the keyboard when the regular keyboard is hidden. Defaults to &lt;em&gt;false&lt;/em&gt;, in which case the custom keyboard can be hidden and opened with a keyboard icon.&lt;/p&gt;\n\nresize_keyboard\n&lt;p&gt;Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons). Defaults to &lt;em&gt;false&lt;/em&gt;, in which case the custom keyboard is always of the same height as the app’s standard keyboard.&lt;/p&gt;\n\none_time_keyboard\n&lt;p&gt;Requests clients to hide the keyboard as soon as it’s been used. The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat - the user can press a special button in the input field to see the custom keyboard again. Defaults to &lt;em&gt;false&lt;/em&gt;.&lt;/p&gt;\n\ninput_field_placeholder\n&lt;p&gt;The placeholder to be shown in the input field when the keyboard is active; 1-64 characters&lt;/p&gt;\n\nselective\n&lt;p&gt;Use this parameter if you want to show the keyboard to specific users only. Targets: 1) users that are @mentioned in the text of the &lt;a href=&quot;https://core.telegram.org/bots/api#message&quot;&gt;Message&lt;/a&gt; object; 2) if the bot’s message is a reply to a message in the same chat and forum topic, sender of the original message.&lt;/p&gt;\n&lt;p&gt;&lt;em&gt;Example&lt;/em&gt;: A user requests to change the bot’s language, bot replies to the request with a keyboard to select the new language. Other users in the group don’t see the keyboard.&lt;/p&gt;\n\nReplyKeyboardRemove(\n  remove_keyboard: Bool,\n  selective: Option(Bool),\n)\n Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see [ReplyKeyboardMarkup](https://core.telegram.org/bots/api#replykeyboardmarkup)).\n\n **Official reference:** https://core.telegram.org/bots/api#replykeyboardremove\nremove_keyboard\n&lt;p&gt;Requests clients to remove the custom keyboard (user will not be able to summon this keyboard; if you want to hide the keyboard from sight but keep it accessible, use &lt;em&gt;one_time_keyboard&lt;/em&gt; in &lt;a href=&quot;https://core.telegram.org/bots/api#replykeyboardmarkup&quot;&gt;ReplyKeyboardMarkup&lt;/a&gt;)&lt;/p&gt;\n\nselective\n&lt;p&gt;Use this parameter if you want to show the keyboard to specific users only. Targets: 1) users that are @mentioned in the text of the &lt;a href=&quot;https://core.telegram.org/bots/api#message&quot;&gt;Message&lt;/a&gt; object; 2) if the bot’s message is a reply to a message in the same chat and forum topic, sender of the original message.&lt;/p&gt;\n&lt;p&gt;&lt;em&gt;Example&lt;/em&gt;: A user requests to change the bot’s language, bot replies to the request with a keyboard to select the new language. Other users in the group don’t see the keyboard.&lt;/p&gt;\n\nForceReply(\n  force_reply: Bool,\n  input_field_placeholder: String,\n  selective: Bool,\n)\n Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot&#39;s message and tapped &#39;Reply&#39;). This can be extremely useful if you want to create user-friendly step-by-step interfaces without having to sacrifice [privacy mode](https://core.telegram.org/bots/features#privacy-mode).\n\n **Official reference:** https://core.telegram.org/bots/api#forcereply\nforce_reply\n&lt;p&gt;Shows reply interface to the user, as if they manually selected the bot’s message and tapped ‘Reply’&lt;/p&gt;\n\ninput_field_placeholder\n&lt;p&gt;The placeholder to be shown in the input field when the reply is active; 1-64 characters&lt;/p&gt;\n\nselective\n&lt;p&gt;Use this parameter if you want to force reply from specific users only. Targets: 1) users that are @mentioned in the text of the &lt;a href=&quot;https://core.telegram.org/bots/api#message&quot;&gt;Message&lt;/a&gt; object; 2) if the bot’s message is a reply to a message in the same chat and forum topic, sender of the original message.&lt;/p&gt;\n\nSynonyms:\ntelega/model.ReplyMarkup\ntelega/model ReplyMarkup","url":"telega/model.html#ReplyMarkup"},{"doc":"telega/model","title":"ReplyParameters","content":"pub type ReplyParameters {\n  ReplyParameters(\n    message_id: Int,\n    chat_id: Option(IntOrString),\n    allow_sending_without_reply: Option(Bool),\n    quote: Option(String),\n    quote_parse_mode: Option(String),\n    quote_entities: Option(List(MessageEntity)),\n    quote_position: Option(Int),\n  )\n}\n\nReplyParameters(\n  message_id: Int,\n  chat_id: Option(IntOrString),\n  allow_sending_without_reply: Option(Bool),\n  quote: Option(String),\n  quote_parse_mode: Option(String),\n  quote_entities: Option(List(MessageEntity)),\n  quote_position: Option(Int),\n)\n Describes reply parameters for the message that is being sent.\n\n **Official reference:** https://core.telegram.org/bots/api#replyparameters\nmessage_id\n&lt;p&gt;Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified&lt;/p&gt;\n\nchat_id\n&lt;p&gt;If the message to be replied to is from a different chat, unique identifier for the chat or username of the channel (in the format &lt;code&gt;@channelusername&lt;/code&gt;)&lt;/p&gt;\n\nallow_sending_without_reply\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; if the message should be sent even if the specified message to be replied to is not found; can be used only for replies in the same chat and forum topic.&lt;/p&gt;\n\nquote\n&lt;p&gt;Quoted part of the message to be replied to; 0-1024 characters after entities parsing. The quote must be an exact substring of the message to be replied to, including &lt;em&gt;bold&lt;/em&gt;, &lt;em&gt;italic&lt;/em&gt;, &lt;em&gt;underline&lt;/em&gt;, &lt;em&gt;strikethrough&lt;/em&gt;, &lt;em&gt;spoiler&lt;/em&gt;, and &lt;em&gt;custom_emoji&lt;/em&gt; entities. The message will fail to send if the quote isn’t found in the original message.&lt;/p&gt;\n\nquote_parse_mode\n&lt;p&gt;Mode for parsing entities in the quote. See &lt;a href=&quot;https://core.telegram.org/bots/api#formatting-options&quot;&gt;formatting options&lt;/a&gt; for more details.&lt;/p&gt;\n\nquote_entities\n&lt;p&gt;A JSON-serialized list of special entities that appear in the quote. It can be specified instead of &lt;em&gt;quote_parse_mode&lt;/em&gt;.&lt;/p&gt;\n\nquote_position\n&lt;p&gt;Position of the quote in the original message in UTF-16 code units&lt;/p&gt;\n\nSynonyms:\ntelega/model.ReplyParameters\ntelega/model ReplyParameters","url":"telega/model.html#ReplyParameters"},{"doc":"telega/model","title":"SendDiceParameters","content":"pub type SendDiceParameters {\n  SendDiceParameters(\n    chat_id: IntOrString,\n    message_thread_id: Option(Int),\n    emoji: Option(String),\n    disable_notification: Option(Bool),\n    protect_content: Option(Bool),\n    reply_parameters: Option(ReplyParameters),\n  )\n}\n\nSendDiceParameters(\n  chat_id: IntOrString,\n  message_thread_id: Option(Int),\n  emoji: Option(String),\n  disable_notification: Option(Bool),\n  protect_content: Option(Bool),\n  reply_parameters: Option(ReplyParameters),\n)\n\nmessage_thread_id\n&lt;p&gt;Unique identifier for the target message thread (topic) of the forum; for forum supergroups only&lt;/p&gt;\n\nemoji\n&lt;p&gt;Emoji on which the dice throw animation is based. Currently, must be one of “🎲”, “🎯”, “🏀”, “⚽”, “🎳”, or “🎰”. Dice can have values 1-6 for “🎲”, “🎯” and “🎳”, values 1-5 for “🏀” and “⚽”, and values 1-64 for “🎰”. Defaults to “🎲”&lt;/p&gt;\n\ndisable_notification\n&lt;p&gt;Sends the message &lt;a href=&quot;https://telegram.org/blog/channels-2-0#silent-messages&quot;&gt;silently&lt;/a&gt;. Users will receive a notification with no sound.&lt;/p&gt;\n\nprotect_content\n&lt;p&gt;Protects the contents of the sent message from forwarding&lt;/p&gt;\n\nreply_parameters\n&lt;p&gt;Description of the message to reply to&lt;/p&gt;\n\nSynonyms:\ntelega/model.SendDiceParameters\ntelega/model SendDiceParameters","url":"telega/model.html#SendDiceParameters"},{"doc":"telega/model","title":"SendMessageParameters","content":"pub type SendMessageParameters {\n  SendMessageParameters(\n    business_connection_id: Option(String),\n    chat_id: IntOrString,\n    message_thread_id: Option(Int),\n    text: String,\n    parse_mode: Option(String),\n    entities: Option(List(MessageEntity)),\n    link_preview_options: Option(LinkPreviewOptions),\n    disable_notification: Option(Bool),\n    protect_content: Option(Bool),\n    reply_parameters: Option(ReplyParameters),\n    reply_markup: Option(ReplyMarkup),\n  )\n}\n\nSendMessageParameters(\n  business_connection_id: Option(String),\n  chat_id: IntOrString,\n  message_thread_id: Option(Int),\n  text: String,\n  parse_mode: Option(String),\n  entities: Option(List(MessageEntity)),\n  link_preview_options: Option(LinkPreviewOptions),\n  disable_notification: Option(Bool),\n  protect_content: Option(Bool),\n  reply_parameters: Option(ReplyParameters),\n  reply_markup: Option(ReplyMarkup),\n)\n Parameters to send using the [sendMessage](https://core.telegram.org/bots/api#sendmessage) method\nbusiness_connection_id\n&lt;p&gt;Unique identifier of the business connection on behalf of which the message will be sent&lt;/p&gt;\n\nchat_id\n&lt;p&gt;Unique identifier for the target chat or username of the target channel (in the format &lt;code&gt;@channelusername&lt;/code&gt;)&lt;/p&gt;\n\nmessage_thread_id\n&lt;p&gt;Unique identifier for the target message thread (topic) of the forum; for forum supergroups only&lt;/p&gt;\n\ntext\n&lt;p&gt;Text of the message to be sent, 1-4096 characters after entities parsing&lt;/p&gt;\n\nparse_mode\n&lt;p&gt;Mode for parsing entities in the message text. See &lt;a href=&quot;https://core.telegram.org/bots/api#formatting-options&quot;&gt;formatting options&lt;/a&gt; for more details.&lt;/p&gt;\n\nentities\n&lt;p&gt;A JSON-serialized list of special entities that appear in message text, which can be specified instead of &lt;em&gt;parse_mode&lt;/em&gt;&lt;/p&gt;\n\nlink_preview_options\n&lt;p&gt;Link preview generation options for the message&lt;/p&gt;\n\ndisable_notification\n&lt;p&gt;Sends the message &lt;a href=&quot;https://telegram.org/blog/channels-2-0#silent-messages&quot;&gt;silently&lt;/a&gt;. Users will receive a notification with no sound.&lt;/p&gt;\n\nprotect_content\n&lt;p&gt;Protects the contents of the sent message from forwarding and saving&lt;/p&gt;\n\nreply_parameters\n&lt;p&gt;Description of the message to reply to&lt;/p&gt;\n\nreply_markup\n&lt;p&gt;Additional interface options. A JSON-serialized object for an &lt;a href=&quot;https://core.telegram.org/bots/features#inline-keyboards&quot;&gt;inline keyboard&lt;/a&gt;, &lt;a href=&quot;https://core.telegram.org/bots/features#keyboards&quot;&gt;custom reply keyboard&lt;/a&gt;, instructions to remove a reply keyboard or to force a reply from the user. Not supported for messages sent on behalf of a business account&lt;/p&gt;\n\nSynonyms:\ntelega/model.SendMessageParameters\ntelega/model SendMessageParameters","url":"telega/model.html#SendMessageParameters"},{"doc":"telega/model","title":"SetChatMenuButtonParameters","content":"pub type SetChatMenuButtonParameters {\n  SetChatMenuButtonParameters(\n    chat_id: Option(Int),\n    menu_button: Option(MenuButton),\n  )\n}\n\nSetChatMenuButtonParameters(\n  chat_id: Option(Int),\n  menu_button: Option(MenuButton),\n)\n\nchat_id\n&lt;p&gt;Unique identifier for the target private chat. If not specified, default bot’s menu button will be changed&lt;/p&gt;\n\nmenu_button\n&lt;p&gt;A JSON-serialized object for the bot’s new menu button. Defaults to MenuButtonDefault&lt;/p&gt;\n\nSynonyms:\ntelega/model.SetChatMenuButtonParameters\ntelega/model SetChatMenuButtonParameters","url":"telega/model.html#SetChatMenuButtonParameters"},{"doc":"telega/model","title":"SetWebhookParameters","content":"pub type SetWebhookParameters {\n  SetWebhookParameters(\n    url: String,\n    max_connections: Option(Int),\n    ip_address: Option(String),\n    allowed_updates: Option(List(String)),\n    drop_pending_updates: Option(Bool),\n    secret_token: Option(String),\n  )\n}\n https://core.telegram.org/bots/api#setwebhook\nSetWebhookParameters(\n  url: String,\n  max_connections: Option(Int),\n  ip_address: Option(String),\n  allowed_updates: Option(List(String)),\n  drop_pending_updates: Option(Bool),\n  secret_token: Option(String),\n)\n\nurl\n&lt;p&gt;HTTPS url to send updates to. Use an empty string to remove webhook integration&lt;/p&gt;\n\nmax_connections\n&lt;p&gt;Maximum allowed number of simultaneous HTTPS connections to the webhook for update delivery, 1-100. Defaults to 40. Use lower values to limit the load on your bot’s server, and higher values to increase your bot’s throughput.&lt;/p&gt;\n\nip_address\n&lt;p&gt;The fixed IP address which will be used to send webhook requests instead of the IP address resolved through DNS&lt;/p&gt;\n\nallowed_updates\n&lt;p&gt;A JSON-serialized list of the update types you want your bot to receive. For example, specify &lt;code&gt;[&quot;message&quot;, &quot;edited_channel_post&quot;, &quot;callback_query&quot;]&lt;/code&gt; to only receive updates of these types. See &lt;a href=&quot;https://core.telegram.org/bots/api#update&quot;&gt;Update&lt;/a&gt; for a complete list of available update types. Specify an empty list to receive all updates regardless of type (default). If not specified, the previous setting will be used.&lt;/p&gt;\n&lt;blockquote&gt;\n&lt;p&gt;Please note that this parameter doesn’t affect updates created before the call to the setWebhook, so unwanted updates may be received for a short period of time.&lt;/p&gt;\n&lt;/blockquote&gt;\n\ndrop_pending_updates\n&lt;p&gt;Pass &lt;em&gt;True&lt;/em&gt; to drop all pending updates&lt;/p&gt;\n\nsecret_token\n&lt;p&gt;A secret token to be sent in a header “X-Telegram-Bot-Api-Secret-Token” in every webhook request, 1-256 characters. Only characters A-Z, a-z, 0-9, _ and - are allowed. The header is useful to ensure that the request comes from a webhook set by you.&lt;/p&gt;\n\nSynonyms:\ntelega/model.SetWebhookParameters\ntelega/model SetWebhookParameters","url":"telega/model.html#SetWebhookParameters"},{"doc":"telega/model","title":"SwitchInlineQueryChosenChat","content":"pub type SwitchInlineQueryChosenChat {\n  SwitchInlineQueryChosenChat(\n    query: Option(String),\n    allow_user_chats: Option(Bool),\n    allow_bot_chats: Option(Bool),\n    allow_group_chats: Option(Bool),\n    allow_channel_chats: Option(Bool),\n  )\n}\n\nSwitchInlineQueryChosenChat(\n  query: Option(String),\n  allow_user_chats: Option(Bool),\n  allow_bot_chats: Option(Bool),\n  allow_group_chats: Option(Bool),\n  allow_channel_chats: Option(Bool),\n)\n This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.\nquery\n&lt;p&gt;The default inline query to be inserted in the input field. If left empty, only the bot’s username will be inserted&lt;/p&gt;\n\nallow_user_chats\n&lt;p&gt;True, if private chats with users can be chosen&lt;/p&gt;\n\nallow_bot_chats\n&lt;p&gt;True, if private chats with bots can be chosen&lt;/p&gt;\n\nallow_group_chats\n&lt;p&gt;True, if group and supergroup chats can be chosen&lt;/p&gt;\n\nallow_channel_chats\n&lt;p&gt;True, if channel chats can be chosen&lt;/p&gt;\n\nSynonyms:\ntelega/model.SwitchInlineQueryChosenChat\ntelega/model SwitchInlineQueryChosenChat","url":"telega/model.html#SwitchInlineQueryChosenChat"},{"doc":"telega/model","title":"Update","content":"pub type Update {\n  Update(\n    update_id: Int,\n    message: Option(Message),\n    edited_message: Option(Message),\n    callback_query: Option(CallbackQuery),\n  )\n}\n\nUpdate(\n  update_id: Int,\n  message: Option(Message),\n  edited_message: Option(Message),\n  callback_query: Option(CallbackQuery),\n)\n **Official reference:** https://core.telegram.org/bots/api#update\nupdate_id\n&lt;p&gt;The update’s unique identifier. Update identifiers start from a certain positive number and increase sequentially.\nThis identifier becomes especially handy if you’re using webhooks, since it allows you to ignore repeated updates or to restore the correct update sequence, should they get out of order.\nIf there are no new updates for at least a week, then identifier of the next update will be chosen randomly instead of sequentially.&lt;/p&gt;\n\nmessage\n&lt;p&gt;New incoming message of any kind - text, photo, sticker, etc.&lt;/p&gt;\n\nedited_message\n&lt;p&gt;New version of a message that is known to the bot and was edited.\nThis update may at times be triggered by changes to message fields that are either unavailable or not actively used by your bot.&lt;/p&gt;\n\ncallback_query\n&lt;p&gt;New incoming callback query&lt;/p&gt;\n\nSynonyms:\ntelega/model.Update\ntelega/model Update","url":"telega/model.html#Update"},{"doc":"telega/model","title":"User","content":"pub type User {\n  User(\n    id: Int,\n    is_bot: Bool,\n    first_name: String,\n    last_name: Option(String),\n    username: Option(String),\n    language_code: Option(String),\n    is_premium: Option(Bool),\n    added_to_attachment_menu: Option(Bool),\n  )\n}\n\nUser(\n  id: Int,\n  is_bot: Bool,\n  first_name: String,\n  last_name: Option(String),\n  username: Option(String),\n  language_code: Option(String),\n  is_premium: Option(Bool),\n  added_to_attachment_menu: Option(Bool),\n)\n **Official reference:** https://core.telegram.org/bots/api#user\nid\n&lt;p&gt;Unique identifier for this user or bot.&lt;/p&gt;\n\nfirst_name\n&lt;p&gt;User’s or bot’s first name&lt;/p&gt;\n\nlast_name\n&lt;p&gt;User’s or bot’s last name&lt;/p&gt;\n\nusername\n&lt;p&gt;Username, for private chats, supergroups and channels if available&lt;/p&gt;\n\nlanguage_code\n&lt;p&gt;&lt;a href=&quot;https://en.wikipedia.org/wiki/IETF_language_tag&quot;&gt;IETF language tag&lt;/a&gt; of the user’s language&lt;/p&gt;\n\nis_premium\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if this user is a Telegram Premium user&lt;/p&gt;\n\nadded_to_attachment_menu\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if this user added the bot to the attachment menu&lt;/p&gt;\n\nSynonyms:\ntelega/model.User\ntelega/model User","url":"telega/model.html#User"},{"doc":"telega/model","title":"WebAppData","content":"pub type WebAppData {\n  WebAppData(data: String, button_text: String)\n}\n\nWebAppData(data: String, button_text: String)\n Describes data sent from a [Web App](https://core.telegram.org/bots/webapps) to the bot.\ndata\n&lt;p&gt;The data. Be aware that a bad client can send arbitrary data in this field.&lt;/p&gt;\n\nbutton_text\n&lt;p&gt;Text of the &lt;em&gt;web_app&lt;/em&gt; keyboard button from which the Web App was opened. Be aware that a bad client can send arbitrary data in this field.&lt;/p&gt;\n\nSynonyms:\ntelega/model.WebAppData\ntelega/model WebAppData","url":"telega/model.html#WebAppData"},{"doc":"telega/model","title":"WebAppInfo","content":"pub type WebAppInfo {\n  WebAppInfo(url: String)\n}\n\nWebAppInfo(url: String)\n Describes a [Web App](https://core.telegram.org/bots/webapps).\n\n **Official reference:** [WebAppInfo](https://core.telegram.org/bots/api#webappinfo)\nurl\n&lt;p&gt;An HTTPS URL of a Web App to be opened with additional data as specified in &lt;a href=&quot;https://core.telegram.org/bots/webapps#initializing-mini-apps&quot;&gt;Initializing Web Apps&lt;/a&gt;&lt;/p&gt;\n\nSynonyms:\ntelega/model.WebAppInfo\ntelega/model WebAppInfo","url":"telega/model.html#WebAppInfo"},{"doc":"telega/model","title":"WebhookInfo","content":"pub type WebhookInfo {\n  WebhookInfo(\n    url: String,\n    has_custom_certificate: Bool,\n    pending_update_count: Int,\n    ip_address: Option(String),\n    last_error_date: Option(Int),\n    last_error_message: Option(String),\n    last_synchronization_error_date: Option(Int),\n    max_connections: Option(Int),\n    allowed_updates: Option(List(String)),\n  )\n}\n\nWebhookInfo(\n  url: String,\n  has_custom_certificate: Bool,\n  pending_update_count: Int,\n  ip_address: Option(String),\n  last_error_date: Option(Int),\n  last_error_message: Option(String),\n  last_synchronization_error_date: Option(Int),\n  max_connections: Option(Int),\n  allowed_updates: Option(List(String)),\n)\n Describes the current status of a webhook.\n\n **Official reference:** [WebhookInfo](https://core.telegram.org/bots/api#webhookinfo)\nurl\n&lt;p&gt;Webhook URL, may be empty if webhook is not set up&lt;/p&gt;\n\nhas_custom_certificate\n&lt;p&gt;&lt;em&gt;True&lt;/em&gt;, if a custom certificate was provided for webhook certificate checks&lt;/p&gt;\n\npending_update_count\n&lt;p&gt;Number of updates awaiting delivery&lt;/p&gt;\n\nip_address\n&lt;p&gt;Currently used webhook IP address&lt;/p&gt;\n\nlast_error_date\n&lt;p&gt;Unix time for the most recent error that happened when trying to deliver an update via webhook&lt;/p&gt;\n\nlast_error_message\n&lt;p&gt;Error message in human-readable format for the most recent error that happened when trying to deliver an update via webhook&lt;/p&gt;\n\nlast_synchronization_error_date\n&lt;p&gt;Maximum allowed payload size for incoming update&lt;/p&gt;\n\nmax_connections\n&lt;p&gt;Maximum allowed number of simultaneous HTTPS connections to the webhook for update delivery&lt;/p&gt;\n\nallowed_updates\n&lt;p&gt;A list of update types the bot is subscribed to. Defaults to all update types&lt;/p&gt;\n\nSynonyms:\ntelega/model.WebhookInfo\ntelega/model WebhookInfo","url":"telega/model.html#WebhookInfo"},{"doc":"telega/model","title":"bot_command_scope_to_json","content":"pub fn bot_command_scope_to_json(scope: BotCommandScope) -&gt; Json\n\nSynonyms:\ntelega/model.bot_command_scope_to_json\ntelega/model bot_command_scope_to_json","url":"telega/model.html#bot_command_scope_to_json"},{"doc":"telega/model","title":"bot_commands_from","content":"pub fn bot_commands_from(\n  commands: List(#(String, String)),\n) -&gt; List(BotCommand)\n\nSynonyms:\ntelega/model.bot_commands_from\ntelega/model bot_commands_from","url":"telega/model.html#bot_commands_from"},{"doc":"telega/model","title":"decode_bot_command","content":"pub fn decode_bot_command(\n  json: Dynamic,\n) -&gt; Result(List(BotCommand), List(DecodeError))\n\nSynonyms:\ntelega/model.decode_bot_command\ntelega/model decode_bot_command","url":"telega/model.html#decode_bot_command"},{"doc":"telega/model","title":"decode_callback_query","content":"pub fn decode_callback_query(\n  json: Dynamic,\n) -&gt; Result(CallbackQuery, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_callback_query\ntelega/model decode_callback_query","url":"telega/model.html#decode_callback_query"},{"doc":"telega/model","title":"decode_edit_message_text_result","content":"pub fn decode_edit_message_text_result(\n  json: Dynamic,\n) -&gt; Result(EditMessageTextResult, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_edit_message_text_result\ntelega/model decode_edit_message_text_result","url":"telega/model.html#decode_edit_message_text_result"},{"doc":"telega/model","title":"decode_file","content":"pub fn decode_file(\n  json: Dynamic,\n) -&gt; Result(File, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_file\ntelega/model decode_file","url":"telega/model.html#decode_file"},{"doc":"telega/model","title":"decode_inaccessible_message","content":"pub fn decode_inaccessible_message(\n  json: Dynamic,\n) -&gt; Result(InaccessibleMessage, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_inaccessible_message\ntelega/model decode_inaccessible_message","url":"telega/model.html#decode_inaccessible_message"},{"doc":"telega/model","title":"decode_inline_button","content":"pub fn decode_inline_button(\n  json: Dynamic,\n) -&gt; Result(InlineKeyboardButton, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_inline_button\ntelega/model decode_inline_button","url":"telega/model.html#decode_inline_button"},{"doc":"telega/model","title":"decode_inline_markup","content":"pub fn decode_inline_markup(\n  json: Dynamic,\n) -&gt; Result(InlineKeyboardMarkup, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_inline_markup\ntelega/model decode_inline_markup","url":"telega/model.html#decode_inline_markup"},{"doc":"telega/model","title":"decode_keyboard_button_request_users","content":"pub fn decode_keyboard_button_request_users(\n  json: Dynamic,\n) -&gt; Result(KeyboardButtonRequestUsers, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_keyboard_button_request_users\ntelega/model decode_keyboard_button_request_users","url":"telega/model.html#decode_keyboard_button_request_users"},{"doc":"telega/model","title":"decode_login_url","content":"pub fn decode_login_url(\n  json: Dynamic,\n) -&gt; Result(LoginUrl, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_login_url\ntelega/model decode_login_url","url":"telega/model.html#decode_login_url"},{"doc":"telega/model","title":"decode_maybe_inaccessible_message","content":"pub fn decode_maybe_inaccessible_message(\n  json: Dynamic,\n) -&gt; Result(MaybeInaccessibleMessage, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_maybe_inaccessible_message\ntelega/model decode_maybe_inaccessible_message","url":"telega/model.html#decode_maybe_inaccessible_message"},{"doc":"telega/model","title":"decode_message","content":"pub fn decode_message(\n  json: Dynamic,\n) -&gt; Result(Message, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_message\ntelega/model decode_message","url":"telega/model.html#decode_message"},{"doc":"telega/model","title":"decode_message_entity","content":"pub fn decode_message_entity(\n  json: Dynamic,\n) -&gt; Result(MessageEntity, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_message_entity\ntelega/model decode_message_entity","url":"telega/model.html#decode_message_entity"},{"doc":"telega/model","title":"decode_switch_inline_query_chosen_chat","content":"pub fn decode_switch_inline_query_chosen_chat(\n  json: Dynamic,\n) -&gt; Result(SwitchInlineQueryChosenChat, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_switch_inline_query_chosen_chat\ntelega/model decode_switch_inline_query_chosen_chat","url":"telega/model.html#decode_switch_inline_query_chosen_chat"},{"doc":"telega/model","title":"decode_update","content":"pub fn decode_update(\n  json: Dynamic,\n) -&gt; Result(Update, List(DecodeError))\n Decode a message from the Telegram API.\nSynonyms:\ntelega/model.decode_update\ntelega/model decode_update","url":"telega/model.html#decode_update"},{"doc":"telega/model","title":"decode_user","content":"pub fn decode_user(\n  json: Dynamic,\n) -&gt; Result(User, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_user\ntelega/model decode_user","url":"telega/model.html#decode_user"},{"doc":"telega/model","title":"decode_web_app_data","content":"pub fn decode_web_app_data(\n  json: Dynamic,\n) -&gt; Result(WebAppData, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_web_app_data\ntelega/model decode_web_app_data","url":"telega/model.html#decode_web_app_data"},{"doc":"telega/model","title":"decode_web_app_info","content":"pub fn decode_web_app_info(\n  json: Dynamic,\n) -&gt; Result(WebAppInfo, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_web_app_info\ntelega/model decode_web_app_info","url":"telega/model.html#decode_web_app_info"},{"doc":"telega/model","title":"decode_webhook_info","content":"pub fn decode_webhook_info(\n  json: Dynamic,\n) -&gt; Result(WebhookInfo, List(DecodeError))\n\nSynonyms:\ntelega/model.decode_webhook_info\ntelega/model decode_webhook_info","url":"telega/model.html#decode_webhook_info"},{"doc":"telega/model","title":"default_botcommand_parameters","content":"pub fn default_botcommand_parameters() -&gt; BotCommandParameters\n\nSynonyms:\ntelega/model.default_botcommand_parameters\ntelega/model default_botcommand_parameters","url":"telega/model.html#default_botcommand_parameters"},{"doc":"telega/model","title":"default_edit_message_text_parameters","content":"pub fn default_edit_message_text_parameters() -&gt; EditMessageTextParameters\n\nSynonyms:\ntelega/model.default_edit_message_text_parameters\ntelega/model default_edit_message_text_parameters","url":"telega/model.html#default_edit_message_text_parameters"},{"doc":"telega/model","title":"encode_answer_callback_query_parameters","content":"pub fn encode_answer_callback_query_parameters(\n  params: AnswerCallbackQueryParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_answer_callback_query_parameters\ntelega/model encode_answer_callback_query_parameters","url":"telega/model.html#encode_answer_callback_query_parameters"},{"doc":"telega/model","title":"encode_botcommand_parameters","content":"pub fn encode_botcommand_parameters(\n  params: BotCommandParameters,\n) -&gt; List(#(String, Json))\n\nSynonyms:\ntelega/model.encode_botcommand_parameters\ntelega/model encode_botcommand_parameters","url":"telega/model.html#encode_botcommand_parameters"},{"doc":"telega/model","title":"encode_chat_administrator_rights","content":"pub fn encode_chat_administrator_rights(\n  chat_administrator_rights: ChatAdministratorRights,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_chat_administrator_rights\ntelega/model encode_chat_administrator_rights","url":"telega/model.html#encode_chat_administrator_rights"},{"doc":"telega/model","title":"encode_edit_message_text_parameters","content":"pub fn encode_edit_message_text_parameters(\n  params: EditMessageTextParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_edit_message_text_parameters\ntelega/model encode_edit_message_text_parameters","url":"telega/model.html#encode_edit_message_text_parameters"},{"doc":"telega/model","title":"encode_forward_message_parameters","content":"pub fn encode_forward_message_parameters(\n  params: ForwardMessageParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_forward_message_parameters\ntelega/model encode_forward_message_parameters","url":"telega/model.html#encode_forward_message_parameters"},{"doc":"telega/model","title":"encode_inline_keyboard_button","content":"pub fn encode_inline_keyboard_button(\n  inline_keyboard_button: InlineKeyboardButton,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_inline_keyboard_button\ntelega/model encode_inline_keyboard_button","url":"telega/model.html#encode_inline_keyboard_button"},{"doc":"telega/model","title":"encode_inline_keyboard_markup","content":"pub fn encode_inline_keyboard_markup(\n  inline_keyboard_markup: InlineKeyboardMarkup,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_inline_keyboard_markup\ntelega/model encode_inline_keyboard_markup","url":"telega/model.html#encode_inline_keyboard_markup"},{"doc":"telega/model","title":"encode_keyboard_button","content":"pub fn encode_keyboard_button(\n  keyboard_button: KeyboardButton,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_keyboard_button\ntelega/model encode_keyboard_button","url":"telega/model.html#encode_keyboard_button"},{"doc":"telega/model","title":"encode_keyboard_button_poll_type","content":"pub fn encode_keyboard_button_poll_type(\n  keyboard_button_poll_type: KeyboardButtonPollType,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_keyboard_button_poll_type\ntelega/model encode_keyboard_button_poll_type","url":"telega/model.html#encode_keyboard_button_poll_type"},{"doc":"telega/model","title":"encode_keyboard_button_request_chat","content":"pub fn encode_keyboard_button_request_chat(\n  keyboard_button_request_chat: KeyboardButtonRequestChat,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_keyboard_button_request_chat\ntelega/model encode_keyboard_button_request_chat","url":"telega/model.html#encode_keyboard_button_request_chat"},{"doc":"telega/model","title":"encode_keyboard_button_request_users","content":"pub fn encode_keyboard_button_request_users(\n  keyboard_button_request_users: KeyboardButtonRequestUsers,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_keyboard_button_request_users\ntelega/model encode_keyboard_button_request_users","url":"telega/model.html#encode_keyboard_button_request_users"},{"doc":"telega/model","title":"encode_link_preview_options","content":"pub fn encode_link_preview_options(\n  link_preview_options: LinkPreviewOptions,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_link_preview_options\ntelega/model encode_link_preview_options","url":"telega/model.html#encode_link_preview_options"},{"doc":"telega/model","title":"encode_login_url","content":"pub fn encode_login_url(login_url: LoginUrl) -&gt; Json\n\nSynonyms:\ntelega/model.encode_login_url\ntelega/model encode_login_url","url":"telega/model.html#encode_login_url"},{"doc":"telega/model","title":"encode_menu_button","content":"pub fn encode_menu_button(menu_button: MenuButton) -&gt; Json\n\nSynonyms:\ntelega/model.encode_menu_button\ntelega/model encode_menu_button","url":"telega/model.html#encode_menu_button"},{"doc":"telega/model","title":"encode_message_entity","content":"pub fn encode_message_entity(\n  message_entity: MessageEntity,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_message_entity\ntelega/model encode_message_entity","url":"telega/model.html#encode_message_entity"},{"doc":"telega/model","title":"encode_reply_markup","content":"pub fn encode_reply_markup(reply_markup: ReplyMarkup) -&gt; Json\n\nSynonyms:\ntelega/model.encode_reply_markup\ntelega/model encode_reply_markup","url":"telega/model.html#encode_reply_markup"},{"doc":"telega/model","title":"encode_reply_parameters","content":"pub fn encode_reply_parameters(\n  reply_parameters: ReplyParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_reply_parameters\ntelega/model encode_reply_parameters","url":"telega/model.html#encode_reply_parameters"},{"doc":"telega/model","title":"encode_send_dice_parameters","content":"pub fn encode_send_dice_parameters(\n  params: SendDiceParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_send_dice_parameters\ntelega/model encode_send_dice_parameters","url":"telega/model.html#encode_send_dice_parameters"},{"doc":"telega/model","title":"encode_send_message_parameters","content":"pub fn encode_send_message_parameters(\n  send_message_parameters: SendMessageParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_send_message_parameters\ntelega/model encode_send_message_parameters","url":"telega/model.html#encode_send_message_parameters"},{"doc":"telega/model","title":"encode_set_chat_menu_button_parametes","content":"pub fn encode_set_chat_menu_button_parametes(\n  params: SetChatMenuButtonParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_set_chat_menu_button_parametes\ntelega/model encode_set_chat_menu_button_parametes","url":"telega/model.html#encode_set_chat_menu_button_parametes"},{"doc":"telega/model","title":"encode_set_webhook_parameters","content":"pub fn encode_set_webhook_parameters(\n  params: SetWebhookParameters,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_set_webhook_parameters\ntelega/model encode_set_webhook_parameters","url":"telega/model.html#encode_set_webhook_parameters"},{"doc":"telega/model","title":"encode_switch_inline_query_chosen_chat","content":"pub fn encode_switch_inline_query_chosen_chat(\n  switch_inline_query_chosen_chat: SwitchInlineQueryChosenChat,\n) -&gt; Json\n\nSynonyms:\ntelega/model.encode_switch_inline_query_chosen_chat\ntelega/model encode_switch_inline_query_chosen_chat","url":"telega/model.html#encode_switch_inline_query_chosen_chat"},{"doc":"telega/model","title":"encode_user","content":"pub fn encode_user(user: User) -&gt; Json\n\nSynonyms:\ntelega/model.encode_user\ntelega/model encode_user","url":"telega/model.html#encode_user"},{"doc":"telega/model","title":"encode_web_app_info","content":"pub fn encode_web_app_info(info: WebAppInfo) -&gt; Json\n\nSynonyms:\ntelega/model.encode_web_app_info\ntelega/model encode_web_app_info","url":"telega/model.html#encode_web_app_info"},{"doc":"telega/model","title":"new_answer_callback_query_parameters","content":"pub fn new_answer_callback_query_parameters(\n  callback_query_id: String,\n) -&gt; AnswerCallbackQueryParameters\n\nSynonyms:\ntelega/model.new_answer_callback_query_parameters\ntelega/model new_answer_callback_query_parameters","url":"telega/model.html#new_answer_callback_query_parameters"},{"doc":"telega/model","title":"new_send_dice_parameters","content":"pub fn new_send_dice_parameters(\n  chat_id chat_id: IntOrString,\n) -&gt; SendDiceParameters\n\nSynonyms:\ntelega/model.new_send_dice_parameters\ntelega/model new_send_dice_parameters","url":"telega/model.html#new_send_dice_parameters"},{"doc":"telega/model","title":"new_send_message_parameters","content":"pub fn new_send_message_parameters(\n  chat_id chat_id: IntOrString,\n  text text: String,\n) -&gt; SendMessageParameters\n\nSynonyms:\ntelega/model.new_send_message_parameters\ntelega/model new_send_message_parameters","url":"telega/model.html#new_send_message_parameters"},{"doc":"telega/model","title":"set_send_message_parameters_reply_markup","content":"pub fn set_send_message_parameters_reply_markup(\n  params: SendMessageParameters,\n  reply_markup: ReplyMarkup,\n) -&gt; SendMessageParameters\n\nSynonyms:\ntelega/model.set_send_message_parameters_reply_markup\ntelega/model set_send_message_parameters_reply_markup","url":"telega/model.html#set_send_message_parameters_reply_markup"},{"doc":"telega/model","title":"telega/model","content":"","url":"telega/model.html"},{"doc":"telega/api","title":"TelegramApiConfig","content":"pub type TelegramApiConfig {\n  TelegramApiConfig(\n    token: String,\n    max_retry_attempts: Int,\n    tg_api_url: String,\n  )\n}\n\nTelegramApiConfig(\n  token: String,\n  max_retry_attempts: Int,\n  tg_api_url: String,\n)\n\nmax_retry_attempts\n&lt;p&gt;The maximum number of times to retry sending a API message. Default is 3.&lt;/p&gt;\n\ntg_api_url\n&lt;p&gt;The Telegram Bot API URL. Default is “https://api.telegram.org”.\nThis is useful for running &lt;a href=&quot;https://core.telegram.org/bots/api#using-a-local-bot-api-server&quot;&gt;a local server&lt;/a&gt;.&lt;/p&gt;\n\nSynonyms:\ntelega/api.TelegramApiConfig\ntelega/api TelegramApiConfig","url":"telega/api.html#TelegramApiConfig"},{"doc":"telega/api","title":"answer_callback_query","content":"pub fn answer_callback_query(\n  config config: TelegramApiConfig,\n  parameters parameters: AnswerCallbackQueryParameters,\n) -&gt; Result(Bool, String)\n Use this method to send answers to callback queries sent from inline keyboards.\n The answer will be displayed to the user as a notification at the top of the chat screen or as an alert.\n On success, _True_ is returned.\n\n **Official reference:** https://core.telegram.org/bots/api#answercallbackquery\nSynonyms:\ntelega/api.answer_callback_query\ntelega/api answer_callback_query","url":"telega/api.html#answer_callback_query"},{"doc":"telega/api","title":"close","content":"pub fn close(\n  config config: TelegramApiConfig,\n) -&gt; Result(Bool, String)\n Use this method to close the bot instance before moving it from one local server to another.\n You need to delete the webhook before calling this method to ensure that the bot isn&#39;t launched again after server restart.\n The method will return error 429 in the first 10 minutes after the bot is launched.\n\n **Official reference:** https://core.telegram.org/bots/api#close\nSynonyms:\ntelega/api.close\ntelega/api close","url":"telega/api.html#close"},{"doc":"telega/api","title":"delete_my_commands","content":"pub fn delete_my_commands(\n  config config: TelegramApiConfig,\n  parameters parameters: Option(BotCommandParameters),\n) -&gt; Result(Bool, String)\n Use this method to delete the list of the bot&#39;s commands for the given scope and user language.\n After deletion, [higher level commands](https://core.telegram.org/bots/api#determining-list-of-commands) will be shown to affected users.\n\n **Official reference:** https://core.telegram.org/bots/api#deletemycommands\nSynonyms:\ntelega/api.delete_my_commands\ntelega/api delete_my_commands","url":"telega/api.html#delete_my_commands"},{"doc":"telega/api","title":"delete_webhook","content":"pub fn delete_webhook(\n  config config: TelegramApiConfig,\n) -&gt; Result(Bool, String)\n Use this method to remove webhook integration if you decide to switch back to [getUpdates](https://core.telegram.org/bots/api#getupdates).\n\n **Official reference:** https://core.telegram.org/bots/api#deletewebhook\nSynonyms:\ntelega/api.delete_webhook\ntelega/api delete_webhook","url":"telega/api.html#delete_webhook"},{"doc":"telega/api","title":"delete_webhook_and_drop_updates","content":"pub fn delete_webhook_and_drop_updates(\n  config config: TelegramApiConfig,\n) -&gt; Result(Bool, String)\n The same as [delete_webhook](#delete_webhook) but also drops all pending updates.\nSynonyms:\ntelega/api.delete_webhook_and_drop_updates\ntelega/api delete_webhook_and_drop_updates","url":"telega/api.html#delete_webhook_and_drop_updates"},{"doc":"telega/api","title":"edit_message_text","content":"pub fn edit_message_text(\n  config config: TelegramApiConfig,\n  parameters parameters: EditMessageTextParameters,\n) -&gt; Result(EditMessageTextResult, String)\n Use this method to edit text and game messages.\n On success, if the edited message is not an inline message, the edited Message is returned, otherwise True is returned.\n\n **Official reference:** https://core.telegram.org/bots/api#editmessagetext\nSynonyms:\ntelega/api.edit_message_text\ntelega/api edit_message_text","url":"telega/api.html#edit_message_text"},{"doc":"telega/api","title":"forward_message","content":"pub fn forward_message(\n  config config: TelegramApiConfig,\n  parameters parameters: ForwardMessageParameters,\n) -&gt; Result(Message, String)\n Use this method to forward messages of any kind. Service messages and messages with protected content can&#39;t be forwarded.\n On success, the sent Message is returned.\n\n **Official reference:** https://core.telegram.org/bots/api#forwardmessage\nSynonyms:\ntelega/api.forward_message\ntelega/api forward_message","url":"telega/api.html#forward_message"},{"doc":"telega/api","title":"get_file","content":"pub fn get_file(\n  config config: TelegramApiConfig,\n  file_id file_id: String,\n) -&gt; Result(File, String)\n\nSynonyms:\ntelega/api.get_file\ntelega/api get_file","url":"telega/api.html#get_file"},{"doc":"telega/api","title":"get_me","content":"pub fn get_me(\n  config config: TelegramApiConfig,\n) -&gt; Result(User, String)\n A simple method for testing your bot&#39;s authentication token.\n\n **Official reference:** https://core.telegram.org/bots/api#getme\nSynonyms:\ntelega/api.get_me\ntelega/api get_me","url":"telega/api.html#get_me"},{"doc":"telega/api","title":"get_my_commands","content":"pub fn get_my_commands(\n  config config: TelegramApiConfig,\n  parameters parameters: Option(BotCommandParameters),\n) -&gt; Result(List(BotCommand), String)\n Use this method to get the current list of the bot&#39;s commands for the given scope and user language.\n\n **Official reference:** https://core.telegram.org/bots/api#getmycommands\nSynonyms:\ntelega/api.get_my_commands\ntelega/api get_my_commands","url":"telega/api.html#get_my_commands"},{"doc":"telega/api","title":"get_webhook_info","content":"pub fn get_webhook_info(\n  config config: TelegramApiConfig,\n) -&gt; Result(WebhookInfo, String)\n Use this method to get current webhook status.\n\n **Official reference:** https://core.telegram.org/bots/api#getwebhookinfo\nSynonyms:\ntelega/api.get_webhook_info\ntelega/api get_webhook_info","url":"telega/api.html#get_webhook_info"},{"doc":"telega/api","title":"log_out","content":"pub fn log_out(\n  config config: TelegramApiConfig,\n) -&gt; Result(Bool, String)\n Use this method to log out from the cloud Bot API server before launching the bot locally.\n You **must** log out the bot before running it locally, otherwise there is no guarantee that the bot will receive updates.\n After a successful call, you can immediately log in on a local server, but will not be able to log in back to the cloud Bot API server for 10 minutes.\n\n **Official reference:** https://core.telegram.org/bots/api#logout\nSynonyms:\ntelega/api.log_out\ntelega/api log_out","url":"telega/api.html#log_out"},{"doc":"telega/api","title":"new_api_config","content":"pub fn new_api_config(token token: String) -&gt; TelegramApiConfig\n\nSynonyms:\ntelega/api.new_api_config\ntelega/api new_api_config","url":"telega/api.html#new_api_config"},{"doc":"telega/api","title":"send_dice","content":"pub fn send_dice(\n  config config: TelegramApiConfig,\n  parameters parameters: SendDiceParameters,\n) -&gt; Result(Message, String)\n Use this method to send an animated emoji that will display a random value.\n\n **Official reference:** https://core.telegram.org/bots/api#senddice\nSynonyms:\ntelega/api.send_dice\ntelega/api send_dice","url":"telega/api.html#send_dice"},{"doc":"telega/api","title":"send_message","content":"pub fn send_message(\n  config config: TelegramApiConfig,\n  parameters parameters: SendMessageParameters,\n) -&gt; Result(Message, String)\n Use this method to send text messages with additional parameters.\n\n **Official reference:** https://core.telegram.org/bots/api#sendmessage\nSynonyms:\ntelega/api.send_message\ntelega/api send_message","url":"telega/api.html#send_message"},{"doc":"telega/api","title":"set_chat_menu_button","content":"pub fn set_chat_menu_button(\n  config config: TelegramApiConfig,\n  parameters parameters: SetChatMenuButtonParameters,\n) -&gt; Result(Bool, String)\n Use this method to change the bot&#39;s menu button in a private chat, or the default menu button. Returns True on success.\n\n **Official reference:** https://core.telegram.org/bots/api#setchatmenubutton\nSynonyms:\ntelega/api.set_chat_menu_button\ntelega/api set_chat_menu_button","url":"telega/api.html#set_chat_menu_button"},{"doc":"telega/api","title":"set_my_commands","content":"pub fn set_my_commands(\n  config config: TelegramApiConfig,\n  commands commands: List(BotCommand),\n  parameters parameters: Option(BotCommandParameters),\n) -&gt; Result(Bool, String)\n Use this method to change the list of the bot&#39;s commands. See [commands documentation](https://core.telegram.org/bots/features#commands) for more details about bot commands.\n\n **Official reference:** https://core.telegram.org/bots/api#setmycommands\nSynonyms:\ntelega/api.set_my_commands\ntelega/api set_my_commands","url":"telega/api.html#set_my_commands"},{"doc":"telega/api","title":"set_webhook","content":"pub fn set_webhook(\n  config config: TelegramApiConfig,\n  parameters parameters: SetWebhookParameters,\n) -&gt; Result(Bool, String)\n Set the webhook URL using [setWebhook](https://core.telegram.org/bots/api#setwebhook) API.\n\n **Official reference:** https://core.telegram.org/bots/api#setwebhook\nSynonyms:\ntelega/api.set_webhook\ntelega/api set_webhook","url":"telega/api.html#set_webhook"},{"doc":"telega/api","title":"telega/api","content":" This module provides an interface for interacting with the Telegram Bot API.\n It will be useful if you want to interact with the Telegram Bot API directly, without running a bot.\n But it will be more convenient to use the `reply` module in bot handlers.","url":"telega/api.html"},{"doc":"telega/update","title":"Command","content":"pub type Command {\n  Command(text: String, command: String, payload: Option(String))\n}\n\nCommand(text: String, command: String, payload: Option(String))\n Represents a command message.\ntext\n&lt;p&gt;Whole command message&lt;/p&gt;\n\ncommand\n&lt;p&gt;Command name without the leading slash&lt;/p&gt;\n\npayload\n&lt;p&gt;The command arguments, if any.&lt;/p&gt;\n\nSynonyms:\ntelega/update.Command\ntelega/update Command","url":"telega/update.html#Command"},{"doc":"telega/update","title":"Update","content":"pub type Update {\n  TextUpdate(chat_id: Int, text: String, raw: Message)\n  CommandUpdate(chat_id: Int, command: Command, raw: Message)\n  CallbackQueryUpdate(from_id: Int, raw: CallbackQuery)\n  UnknownUpdate(raw: ModelUpdate)\n}\n Messages represent the data that the bot receives from the Telegram API.\nTextUpdate(chat_id: Int, text: String, raw: Message)\n\n\nCommandUpdate(chat_id: Int, command: Command, raw: Message)\n\n\nCallbackQueryUpdate(from_id: Int, raw: CallbackQuery)\n\n\nUnknownUpdate(raw: ModelUpdate)\n\n\nSynonyms:\ntelega/update.Update\ntelega/update Update","url":"telega/update.html#Update"},{"doc":"telega/update","title":"decode","content":"pub fn decode(json: Dynamic) -&gt; Result(Update, String)\n Decode a update from the Telegram API to `Update` instance.\nSynonyms:\ntelega/update.decode\ntelega/update decode","url":"telega/update.html#decode"},{"doc":"telega/update","title":"telega/update","content":"","url":"telega/update.html"},{"doc":"telega/bot","title":"BotInstanceMessage","content":"pub type BotInstanceMessage(session) {\n  BotInstanceMessageOk\n  BotInstanceMessageNew(\n    client: BotInstanceSubject(session),\n    update: Update,\n  )\n  BotInstanceMessageWaitHandler(handler: Handler(session))\n}\n\nBotInstanceMessageOk\n\n\nBotInstanceMessageNew(\n  client: BotInstanceSubject(session),\n  update: Update,\n)\n\n\nBotInstanceMessageWaitHandler(handler: Handler(session))\n\n\nSynonyms:\ntelega/bot.BotInstanceMessage\ntelega/bot BotInstanceMessage","url":"telega/bot.html#BotInstanceMessage"},{"doc":"telega/bot","title":"CallbackQueryFilter","content":"pub type CallbackQueryFilter {\n  CallbackQueryFilter(re: Regexp)\n}\n\nCallbackQueryFilter(re: Regexp)\n\n\nSynonyms:\ntelega/bot.CallbackQueryFilter\ntelega/bot CallbackQueryFilter","url":"telega/bot.html#CallbackQueryFilter"},{"doc":"telega/bot","title":"Context","content":"pub type Context(session) {\n  Context(\n    key: String,\n    update: Update,\n    bot_info: User,\n    config: Config,\n    session: session,\n    bot_subject: BotInstanceSubject(session),\n  )\n}\n Handlers context.\nContext(\n  key: String,\n  update: Update,\n  bot_info: User,\n  config: Config,\n  session: session,\n  bot_subject: BotInstanceSubject(session),\n)\n\n\nSynonyms:\ntelega/bot.Context\ntelega/bot Context","url":"telega/bot.html#Context"},{"doc":"telega/bot","title":"Handler","content":"pub type Handler(session) {\n  HandleAll(\n    handler: fn(Context(session)) -&gt; Result(session, String),\n  )\n  HandleCommand(\n    command: String,\n    handler: fn(Context(session), Command) -&gt;\n      Result(session, String),\n  )\n  HandleCommands(\n    commands: List(String),\n    handler: fn(Context(session), Command) -&gt;\n      Result(session, String),\n  )\n  HandleText(\n    handler: fn(Context(session), String) -&gt;\n      Result(session, String),\n  )\n  HandleHears(\n    hears: Hears,\n    handler: fn(Context(session), String) -&gt;\n      Result(session, String),\n  )\n  HandleCallbackQuery(\n    filter: CallbackQueryFilter,\n    handler: fn(Context(session), String, String) -&gt;\n      Result(session, String),\n  )\n}\n\nHandleAll(\n  handler: fn(Context(session)) -&gt; Result(session, String),\n)\n Handle all messages.\n\nHandleCommand(\n  command: String,\n  handler: fn(Context(session), Command) -&gt;\n    Result(session, String),\n)\n Handle a specific command.\n\nHandleCommands(\n  commands: List(String),\n  handler: fn(Context(session), Command) -&gt;\n    Result(session, String),\n)\n Handle multiple commands.\n\nHandleText(\n  handler: fn(Context(session), String) -&gt;\n    Result(session, String),\n)\n Handle text messages.\n\nHandleHears(\n  hears: Hears,\n  handler: fn(Context(session), String) -&gt;\n    Result(session, String),\n)\n Handle text message with a specific substring.\n\nHandleCallbackQuery(\n  filter: CallbackQueryFilter,\n  handler: fn(Context(session), String, String) -&gt;\n    Result(session, String),\n)\n Handle callback query. Context, data from callback query and `callback_query_id` are passed to the handler.\n\nSynonyms:\ntelega/bot.Handler\ntelega/bot Handler","url":"telega/bot.html#Handler"},{"doc":"telega/bot","title":"Hears","content":"pub type Hears {\n  HearText(text: String)\n  HearTexts(texts: List(String))\n  HearRegex(regex: Regexp)\n  HearRegexes(regexes: List(Regexp))\n}\n\nHearText(text: String)\n\n\nHearTexts(texts: List(String))\n\n\nHearRegex(regex: Regexp)\n\n\nHearRegexes(regexes: List(Regexp))\n\n\nSynonyms:\ntelega/bot.Hears\ntelega/bot Hears","url":"telega/bot.html#Hears"},{"doc":"telega/bot","title":"RegistryMessage","content":"pub type RegistryMessage {\n  HandleBotRegistryMessage(update: Update)\n}\n\nHandleBotRegistryMessage(update: Update)\n\n\nSynonyms:\ntelega/bot.RegistryMessage\ntelega/bot RegistryMessage","url":"telega/bot.html#RegistryMessage"},{"doc":"telega/bot","title":"SessionSettings","content":"pub type SessionSettings(session) {\n  SessionSettings(\n    persist_session: fn(String, session) -&gt;\n      Result(session, String),\n    get_session: fn(String) -&gt; Result(session, String),\n  )\n}\n\nSessionSettings(\n  persist_session: fn(String, session) -&gt; Result(session, String),\n  get_session: fn(String) -&gt; Result(session, String),\n)\n\n\nSynonyms:\ntelega/bot.SessionSettings\ntelega/bot SessionSettings","url":"telega/bot.html#SessionSettings"},{"doc":"telega/bot","title":"set_webhook","content":"pub fn set_webhook(config config: Config) -&gt; Result(Bool, String)\n Set webhook for the bot.\nSynonyms:\ntelega/bot.set_webhook\ntelega/bot set_webhook","url":"telega/bot.html#set_webhook"},{"doc":"telega/bot","title":"start_registry","content":"pub fn start_registry(\n  config config: Config,\n  handlers handlers: List(Handler(a)),\n  session_settings session_settings: SessionSettings(a),\n  root_subject root_subject: Subject(Subject(RegistryMessage)),\n  bot_info bot_info: User,\n) -&gt; Result(Subject(RegistryMessage), StartError)\n\nSynonyms:\ntelega/bot.start_registry\ntelega/bot start_registry","url":"telega/bot.html#start_registry"},{"doc":"telega/bot","title":"wait_handler","content":"pub fn wait_handler(\n  ctx: Context(a),\n  handler: Handler(a),\n) -&gt; Result(a, String)\n\nSynonyms:\ntelega/bot.wait_handler\ntelega/bot wait_handler","url":"telega/bot.html#wait_handler"},{"doc":"telega/bot","title":"telega/bot","content":"","url":"telega/bot.html"},{"doc":"telega","title":"Telega","content":"pub opaque type Telega(session)\n\n\nSynonyms:\ntelega.Telega\ntelega Telega","url":"telega.html#Telega"},{"doc":"telega","title":"TelegaBuilder","content":"pub opaque type TelegaBuilder(session)\n\n\nSynonyms:\ntelega.TelegaBuilder\ntelega TelegaBuilder","url":"telega.html#TelegaBuilder"},{"doc":"telega","title":"handle_all","content":"pub fn handle_all(\n  bot builder: TelegaBuilder(a),\n  handler handler: fn(Context(a)) -&gt; Result(a, String),\n) -&gt; TelegaBuilder(a)\n Handles all messages.\nSynonyms:\ntelega.handle_all\ntelega handle_all","url":"telega.html#handle_all"},{"doc":"telega","title":"handle_callback_query","content":"pub fn handle_callback_query(\n  bot builder: TelegaBuilder(a),\n  filter filter: CallbackQueryFilter,\n  handler handler: fn(Context(a), String, String) -&gt;\n    Result(a, String),\n) -&gt; TelegaBuilder(a)\n Handles messages from inline keyboard callback.\nSynonyms:\ntelega.handle_callback_query\ntelega handle_callback_query","url":"telega.html#handle_callback_query"},{"doc":"telega","title":"handle_command","content":"pub fn handle_command(\n  bot builder: TelegaBuilder(a),\n  command command: String,\n  handler handler: fn(Context(a), Command) -&gt; Result(a, String),\n) -&gt; TelegaBuilder(a)\n Handles a specific command.\nSynonyms:\ntelega.handle_command\ntelega handle_command","url":"telega.html#handle_command"},{"doc":"telega","title":"handle_commands","content":"pub fn handle_commands(\n  bot builder: TelegaBuilder(a),\n  commands commands: List(String),\n  handler handler: fn(Context(a), Command) -&gt; Result(a, String),\n) -&gt; TelegaBuilder(a)\n Handles multiple commands.\nSynonyms:\ntelega.handle_commands\ntelega handle_commands","url":"telega.html#handle_commands"},{"doc":"telega","title":"handle_hears","content":"pub fn handle_hears(\n  bot builder: TelegaBuilder(a),\n  hears hears: Hears,\n  handler handler: fn(Context(a), String) -&gt; Result(a, String),\n) -&gt; TelegaBuilder(a)\n Handles messages that match the given `Hears`.\nSynonyms:\ntelega.handle_hears\ntelega handle_hears","url":"telega.html#handle_hears"},{"doc":"telega","title":"handle_text","content":"pub fn handle_text(\n  bot builder: TelegaBuilder(a),\n  handler handler: fn(Context(a), String) -&gt; Result(a, String),\n) -&gt; TelegaBuilder(a)\n Handles text messages.\nSynonyms:\ntelega.handle_text\ntelega handle_text","url":"telega.html#handle_text"},{"doc":"telega","title":"handle_update","content":"pub fn handle_update(\n  telega: Telega(a),\n  update: Update,\n) -&gt; Result(Nil, String)\n Handle an update from the Telegram API.\nSynonyms:\ntelega.handle_update\ntelega handle_update","url":"telega.html#handle_update"},{"doc":"telega","title":"init","content":"pub fn init(\n  builder: TelegaBuilder(a),\n) -&gt; Result(Telega(a), String)\n Initialize a Telega instance.\n This function should be called after all handlers are added.\n It will set the webhook and start the `Registry`.\nSynonyms:\ntelega.init\ntelega init","url":"telega.html#init"},{"doc":"telega","title":"init_nil_session","content":"pub fn init_nil_session(\n  builder: TelegaBuilder(Nil),\n) -&gt; Result(Telega(Nil), String)\n Initialize a Telega instance with a `Nil` session.\n Usefulwhen you don&#39;t need to persist the session.\nSynonyms:\ntelega.init_nil_session\ntelega init_nil_session","url":"telega.html#init_nil_session"},{"doc":"telega","title":"is_secret_token_valid","content":"pub fn is_secret_token_valid(\n  telega: Telega(a),\n  token: String,\n) -&gt; Bool\n Check if a secret token is valid.\n\n Usefull if you plan to implement own adapter.\nSynonyms:\ntelega.is_secret_token_valid\ntelega is_secret_token_valid","url":"telega.html#is_secret_token_valid"},{"doc":"telega","title":"is_webhook_path","content":"pub fn is_webhook_path(telega: Telega(a), path: String) -&gt; Bool\n Check if a path is the webhook path for the bot.\n\n Usefull if you plan to implement own adapter.\nSynonyms:\ntelega.is_webhook_path\ntelega is_webhook_path","url":"telega.html#is_webhook_path"},{"doc":"telega","title":"log_context","content":"pub fn log_context(\n  ctx: Context(a),\n  prefix: String,\n  handler: fn() -&gt; Result(a, String),\n) -&gt; Result(a, String)\n Log the message and error message if the handler fails.\nSynonyms:\ntelega.log_context\ntelega log_context","url":"telega.html#log_context"},{"doc":"telega","title":"new","content":"pub fn new(\n  token token: String,\n  url server_url: String,\n  webhook_path webhook_path: String,\n  secret_token secret_token: Option(String),\n) -&gt; TelegaBuilder(a)\n Create a new Telega instance.\nSynonyms:\ntelega.new\ntelega new","url":"telega.html#new"},{"doc":"telega","title":"wait_any","content":"pub fn wait_any(\n  ctx ctx: Context(a),\n  continue continue: fn(Context(a)) -&gt; Result(a, String),\n) -&gt; Result(a, String)\n Stops bot message handling and waits for any message.\nSynonyms:\ntelega.wait_any\ntelega wait_any","url":"telega.html#wait_any"},{"doc":"telega","title":"wait_callback_query","content":"pub fn wait_callback_query(\n  ctx ctx: Context(a),\n  filter filter: CallbackQueryFilter,\n  continue continue: fn(Context(a), String, String) -&gt;\n    Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\ntelega.wait_callback_query\ntelega wait_callback_query","url":"telega.html#wait_callback_query"},{"doc":"telega","title":"wait_command","content":"pub fn wait_command(\n  ctx ctx: Context(a),\n  command command: String,\n  continue continue: fn(Context(a), Command) -&gt; Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\ntelega.wait_command\ntelega wait_command","url":"telega.html#wait_command"},{"doc":"telega","title":"wait_commands","content":"pub fn wait_commands(\n  ctx ctx: Context(a),\n  commands commands: List(String),\n  continue continue: fn(Context(a), Command) -&gt; Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\ntelega.wait_commands\ntelega wait_commands","url":"telega.html#wait_commands"},{"doc":"telega","title":"wait_hears","content":"pub fn wait_hears(\n  ctx ctx: Context(a),\n  hears hears: Hears,\n  continue continue: fn(Context(a), String) -&gt; Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\ntelega.wait_hears\ntelega wait_hears","url":"telega.html#wait_hears"},{"doc":"telega","title":"wait_text","content":"pub fn wait_text(\n  ctx ctx: Context(a),\n  continue continue: fn(Context(a), String) -&gt; Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\ntelega.wait_text\ntelega wait_text","url":"telega.html#wait_text"},{"doc":"telega","title":"with_session_settings","content":"pub fn with_session_settings(\n  builder: TelegaBuilder(a),\n  persist_session persist_session: fn(String, a) -&gt;\n    Result(a, String),\n  get_session get_session: fn(String) -&gt; Result(a, String),\n) -&gt; TelegaBuilder(a)\n Construct a session settings.\nSynonyms:\ntelega.with_session_settings\ntelega with_session_settings","url":"telega.html#with_session_settings"},{"doc":"telega","title":"telega","content":"","url":"telega.html"},{"doc":"telega/adapters/wisp","title":"handle_bot","content":"pub fn handle_bot(\n  request req: Request(Connection),\n  telega telega: Telega(a),\n  next handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function to handle incoming requests from the Telegram API.\n Handles a request to the bot webhook endpoint, decodes the incoming message,\n validates the secret token, and passes the message to the bot for processing.\n\n \n import wisp.{type Request, type Response}\n import telega.{type Bot}\n import telega/adapters/wisp as telega_wisp\n\n fn handle_request(req: Request, bot: Bot) -&gt; Response {\n   use &lt;- telega_wisp.handle_bot(req)\n   // ...\n }\n \nSynonyms:\ntelega/adapters/wisp.handle_bot\ntelega/adapters/wisp handle_bot","url":"telega/adapters/wisp.html#handle_bot"},{"doc":"telega/adapters/wisp","title":"telega/adapters/wisp","content":"","url":"telega/adapters/wisp.html"},{"doc":"telega/keyboard","title":"InlineKeyboard","content":"pub opaque type InlineKeyboard\n\n\nSynonyms:\ntelega/keyboard.InlineKeyboard\ntelega/keyboard InlineKeyboard","url":"telega/keyboard.html#InlineKeyboard"},{"doc":"telega/keyboard","title":"Keyboard","content":"pub opaque type Keyboard\n\n\nSynonyms:\ntelega/keyboard.Keyboard\ntelega/keyboard Keyboard","url":"telega/keyboard.html#Keyboard"},{"doc":"telega/keyboard","title":"KeyboardCallback","content":"pub type KeyboardCallback(data) {\n  KeyboardCallback(\n    data: data,\n    id: String,\n    payload: String,\n    callback_data: KeyboardCallbackData(data),\n  )\n}\n\nKeyboardCallback(\n  data: data,\n  id: String,\n  payload: String,\n  callback_data: KeyboardCallbackData(data),\n)\n\n\nSynonyms:\ntelega/keyboard.KeyboardCallback\ntelega/keyboard KeyboardCallback","url":"telega/keyboard.html#KeyboardCallback"},{"doc":"telega/keyboard","title":"KeyboardCallbackData","content":"pub opaque type KeyboardCallbackData(data)\n\n\nSynonyms:\ntelega/keyboard.KeyboardCallbackData\ntelega/keyboard KeyboardCallbackData","url":"telega/keyboard.html#KeyboardCallbackData"},{"doc":"telega/keyboard","title":"build","content":"pub fn build(keyboard: Keyboard) -&gt; ReplyMarkup\n Build a reply markup for `Message` from a keyboard\nSynonyms:\ntelega/keyboard.build\ntelega/keyboard build","url":"telega/keyboard.html#build"},{"doc":"telega/keyboard","title":"build_inline","content":"pub fn build_inline(keyboard: InlineKeyboard) -&gt; ReplyMarkup\n Build a reply markup for `Message` from an inline keyboard\nSynonyms:\ntelega/keyboard.build_inline\ntelega/keyboard build_inline","url":"telega/keyboard.html#build_inline"},{"doc":"telega/keyboard","title":"button","content":"pub fn button(text: String) -&gt; KeyboardButton\n Create a new keyboard button\nSynonyms:\ntelega/keyboard.button\ntelega/keyboard button","url":"telega/keyboard.html#button"},{"doc":"telega/keyboard","title":"filter_inline_keyboard_query","content":"pub fn filter_inline_keyboard_query(\n  keyboard: InlineKeyboard,\n) -&gt; CallbackQueryFilter\n\nSynonyms:\ntelega/keyboard.filter_inline_keyboard_query\ntelega/keyboard filter_inline_keyboard_query","url":"telega/keyboard.html#filter_inline_keyboard_query"},{"doc":"telega/keyboard","title":"hear","content":"pub fn hear(keyboard: Keyboard) -&gt; Hears\n\nSynonyms:\ntelega/keyboard.hear\ntelega/keyboard hear","url":"telega/keyboard.html#hear"},{"doc":"telega/keyboard","title":"inline_button","content":"pub fn inline_button(\n  text text: String,\n  callback_data callback_data: KeyboardCallback(a),\n) -&gt; InlineKeyboardButton\n Create a new inline button\nSynonyms:\ntelega/keyboard.inline_button\ntelega/keyboard inline_button","url":"telega/keyboard.html#inline_button"},{"doc":"telega/keyboard","title":"new","content":"pub fn new(buttons: List(List(KeyboardButton))) -&gt; Keyboard\n Create a new keyboard\nSynonyms:\ntelega/keyboard.new\ntelega/keyboard new","url":"telega/keyboard.html#new"},{"doc":"telega/keyboard","title":"new_callback_data","content":"pub fn new_callback_data(\n  id id: String,\n  serilize serilize: fn(a) -&gt; String,\n  deserialize deserialize: fn(String) -&gt; a,\n) -&gt; KeyboardCallbackData(a)\n Create a new callback data for inline keyboard buttons\nSynonyms:\ntelega/keyboard.new_callback_data\ntelega/keyboard new_callback_data","url":"telega/keyboard.html#new_callback_data"},{"doc":"telega/keyboard","title":"new_inline","content":"pub fn new_inline(\n  buttons: List(List(InlineKeyboardButton)),\n) -&gt; InlineKeyboard\n Create a new inline keyboard\nSynonyms:\ntelega/keyboard.new_inline\ntelega/keyboard new_inline","url":"telega/keyboard.html#new_inline"},{"doc":"telega/keyboard","title":"one_time","content":"pub fn one_time(keyboard: Keyboard) -&gt; Keyboard\n Make the keyboard one-time\nSynonyms:\ntelega/keyboard.one_time\ntelega/keyboard one_time","url":"telega/keyboard.html#one_time"},{"doc":"telega/keyboard","title":"pack_callback","content":"pub fn pack_callback(\n  callback_data callback_data: KeyboardCallbackData(a),\n  data data: a,\n) -&gt; KeyboardCallback(a)\n Pack callback data into a callback\nSynonyms:\ntelega/keyboard.pack_callback\ntelega/keyboard pack_callback","url":"telega/keyboard.html#pack_callback"},{"doc":"telega/keyboard","title":"persistent","content":"pub fn persistent(keyboard: Keyboard) -&gt; Keyboard\n Make the keyboard persistent\nSynonyms:\ntelega/keyboard.persistent\ntelega/keyboard persistent","url":"telega/keyboard.html#persistent"},{"doc":"telega/keyboard","title":"placeholder","content":"pub fn placeholder(keyboard: Keyboard, text: String) -&gt; Keyboard\n Set the placeholder for the input field\nSynonyms:\ntelega/keyboard.placeholder\ntelega/keyboard placeholder","url":"telega/keyboard.html#placeholder"},{"doc":"telega/keyboard","title":"resized","content":"pub fn resized(keyboard: Keyboard) -&gt; Keyboard\n Make the keyboard resizable\nSynonyms:\ntelega/keyboard.resized\ntelega/keyboard resized","url":"telega/keyboard.html#resized"},{"doc":"telega/keyboard","title":"selected","content":"pub fn selected(keyboard: Keyboard) -&gt; Keyboard\n Make the keyboard selective.\n Use this parameter if you want to show the keyboard to specific users only.\nSynonyms:\ntelega/keyboard.selected\ntelega/keyboard selected","url":"telega/keyboard.html#selected"},{"doc":"telega/keyboard","title":"set_callback_data_delimiter","content":"pub fn set_callback_data_delimiter(\n  data: KeyboardCallbackData(a),\n  delimiter: String,\n) -&gt; KeyboardCallbackData(a)\n Change the delimiter for the callback data, usefull if you need to use `:` in the id\nSynonyms:\ntelega/keyboard.set_callback_data_delimiter\ntelega/keyboard set_callback_data_delimiter","url":"telega/keyboard.html#set_callback_data_delimiter"},{"doc":"telega/keyboard","title":"unpack_callback","content":"pub fn unpack_callback(\n  payload payload: String,\n  callback_data callback_data: KeyboardCallbackData(a),\n) -&gt; Result(KeyboardCallback(a), Nil)\n Unpack payload into a callback\nSynonyms:\ntelega/keyboard.unpack_callback\ntelega/keyboard unpack_callback","url":"telega/keyboard.html#unpack_callback"},{"doc":"telega/keyboard","title":"telega/keyboard","content":" This module contains the keyboard constructors and usefull utilities to work with keyboards","url":"telega/keyboard.html"},{"doc":"telega/reply","title":"answer_callback_query","content":"pub fn answer_callback_query(\n  ctx ctx: Context(a),\n  parameters parameters: AnswerCallbackQueryParameters,\n) -&gt; Result(Bool, String)\n Use this method to send answers to callback queries sent from inline keyboards.\n The answer will be displayed to the user as a notification at the top of the chat screen or as an alert.\n On success, _True_ is returned.\n\n **Official reference:** https://core.telegram.org/bots/api#answercallbackquery\nSynonyms:\ntelega/reply.answer_callback_query\ntelega/reply answer_callback_query","url":"telega/reply.html#answer_callback_query"},{"doc":"telega/reply","title":"edit_text","content":"pub fn edit_text(\n  ctx ctx: Context(a),\n  parameters parameters: EditMessageTextParameters,\n) -&gt; Result(EditMessageTextResult, String)\n Use this method to edit text and game messages.\n On success, if the edited message is not an inline message, the edited Message is returned, otherwise True is returned.\n\n **Official reference:** https://core.telegram.org/bots/api#editmessagetext\nSynonyms:\ntelega/reply.edit_text\ntelega/reply edit_text","url":"telega/reply.html#edit_text"},{"doc":"telega/reply","title":"forward","content":"pub fn forward(\n  ctx ctx: Context(a),\n  parameters parameters: ForwardMessageParameters,\n) -&gt; Result(Message, String)\n Use this method to forward messages of any kind. Service messages and messages with protected content can&#39;t be forwarded.\n On success, the sent Message is returned.\n\n **Official reference:** https://core.telegram.org/bots/api#forwardmessage\nSynonyms:\ntelega/reply.forward\ntelega/reply forward","url":"telega/reply.html#forward"},{"doc":"telega/reply","title":"with_dice","content":"pub fn with_dice(\n  ctx ctx: Context(a),\n  parameters parameters: Option(SendDiceParameters),\n) -&gt; Result(Message, String)\n Use this method to send an animated emoji that will display a random value.\n\n **Official reference:** https://core.telegram.org/bots/api#senddice\nSynonyms:\ntelega/reply.with_dice\ntelega/reply with_dice","url":"telega/reply.html#with_dice"},{"doc":"telega/reply","title":"with_file_link","content":"pub fn with_file_link(\n  ctx ctx: Context(a),\n  file_id file_id: String,\n) -&gt; Result(String, String)\n Get download link for the file.\nSynonyms:\ntelega/reply.with_file_link\ntelega/reply with_file_link","url":"telega/reply.html#with_file_link"},{"doc":"telega/reply","title":"with_markup","content":"pub fn with_markup(\n  ctx ctx: Context(a),\n  text text: String,\n  markup reply_markup: ReplyMarkup,\n) -&gt; Result(Message, String)\n Use this method to send text messages with keyboard markup.\n\n **Official reference:** https://core.telegram.org/bots/api#sendmessage\nSynonyms:\ntelega/reply.with_markup\ntelega/reply with_markup","url":"telega/reply.html#with_markup"},{"doc":"telega/reply","title":"with_text","content":"pub fn with_text(\n  ctx ctx: Context(a),\n  text text: String,\n) -&gt; Result(Message, String)\n Use this method to send text messages.\n\n **Official reference:** https://core.telegram.org/bots/api#sendmessage\nSynonyms:\ntelega/reply.with_text\ntelega/reply with_text","url":"telega/reply.html#with_text"},{"doc":"telega/reply","title":"telega/reply","content":"","url":"telega/reply.html"}]);